@@ -12,17 +12,18 @@ proc manReadSects {{w .man} {force 0} {msg "Building database ..."}} {
 	set manx(hunkcnt) 0
 	set hunkcode(0) manReadRecentDone
 	# kill one in progress, if any
-	if {$manx(hunkid)!=""} {after cancel $manx(hunkid)}
+	if {![string equal $manx(hunkid) ""]} {after cancel $manx(hunkid)}
 
 	set manx(manList) ""; set manx(manTitleList) ""; set manx(mandot) ""
 	set lastv ""
 	set total 0
 	catch {unset manc}
+	set manx(stray-warnings) ""
 
 	set buildtime [time {
 	foreach i $mani(manList) j $mani(manTitleList) {
-		set nowv [string range $i 0 0]
-		if {$nowv==$lastv} {set more [string range $i 1 end]} {set more " $i"}
+		set nowv [string index $i 0]
+		if {[string equal $nowv $lastv]} {set more [string range $i 1 end]} else {set more " $i"}
 		set lastv $nowv
 		manWinstdout $w "[manWinstdout $w]$more" 1
 		if {[set cnt [manReadSection $i]]} {
@@ -37,7 +38,7 @@ proc manReadSects {{w .man} {force 0} {msg "Building database ..."}} {
 	manWinstdout $w "Read $total pages"
 	set manx(db-pagecnt) $total
 
-	if ![llength $manx(manList)] {
+	if {![llength $manx(manList)]} {
 		puts stderr "Can't find any man pages!"
 		puts stderr "MANPATH = $env(MANPATH)"
 		exit 1
@@ -82,7 +83,7 @@ proc manLatestMan {root} {
 
 	set men [glob -nocomplain "$root/man?*"]
 	# in cat-only situation?
-	if {$men==""} {
+	if {[string equal $men ""]} {
 		set men [glob -nocomplain "$root/*"]
 		#if [catch {set men [exec $man(find) $root -type d -print]} info] { set men $info }
 	}
@@ -122,8 +123,7 @@ proc manReadRecent {sect files recentdef hunknext} {
 #puts "length of manReadRecent list = [llength $files]"
 	foreach f $files {
 		catch {
-#			if {[file readable $f] && [file isfile $f] && [file mtime $f]>$recentdef && ![string match "*~" $f] && ![string match "*.bak" $f]} {
-#			if {![string match "*~" $f] && ![string match "*.bak" $f] && [file mtime $f]>$recentdef && [file isfile $f]} {
+			# also [file readable $f]?
 			if {![regexp "$manx(bkupregexp)\$" $f] && [file mtime $f]>$recentdef && [file isfile $f]} {
 #puts "adding $f"
 				lappend hunk($sect) [zapZ [file tail $f]]
@@ -142,7 +142,7 @@ proc manReadRecentDone {} {
 
 DEBUG {puts "RECENT DONE, hunk array: [array names hunk]"}
 	foreach n [array names hunk] {
-		if {$hunk($n)!=""} {lappend manx(newmen) [list $n [lsort $hunk($n)]]}
+		if {![string equal $hunk($n) ""]} {lappend manx(newmen) [list $n [lsort $hunk($n)]]}
 	}
 
 	.vols entryconfigure "Recently*" -state normal -label "Recently added/changed"
@@ -160,84 +160,118 @@ proc manReadSection {n} {
 	global man manx mani manc hunk hunkcode env
 
 	# follow all paths here, even if search presently turned off for that dir
-	if ![llength $mani($n,dirs)] {return 0}
+	if {![llength $mani($n,dirs)]} {return 0}
+	# regexps common to man and cat
+	set zbkup " \[^ \]+$manx(bkupregexp) "
+	set znodot { [^ \.]+ } 
+	set zsect {\.[^\. ]* }
+	set ztclmeta {([][{}"])}
+
 
 DEBUG { puts -nonewline stderr $n }
 	set first 1
-	set cnt 0
 
 	# collect recent additions/changes
 	# need -maxdepth *0* on find for SGI's nested directories, but only gfind has it so homebrew
-	set recentdef [expr [clock seconds]-$man(recentdays)*24*60*60]
+	set recentdef [expr {[clock seconds]-$man(recentdays)*24*60*60}]
 	# make this an after idle event.  recent section not available for ~10 seconds--who'll notice?
 	
 	# chop up files to mtime into hunks that aren't noticable to user interaction
 	# would like to have threads for this
+	# => just do this on demand when choose that section?
 	set hunksize 25
 	foreach i $mani($n,dirs) {
 		set dirtime [file mtime $i]
+		# not foolproof test: could just change pages
 		if {$dirtime>$recentdef} {
 			set mtimeme [glob -nocomplain $i/*]
 #puts "$i"
 			set hunk($n) {}
-#			for {set j 0} \$j<[llength $mtimeme] {incr j $hunksize} {
 			for {set j 0} {$j<[llength $mtimeme]} {incr j $hunksize} {
 				set hunknow $manx(hunkcnt); set hunknext [incr manx(hunkcnt)]
 				# push last guy down
 				set hunkcode($hunknext) $hunkcode($hunknow)
 
 #puts "\tmaking hunk #$manx(hunkcnt) @ $j"
-				set hunkcode($hunknow) "manReadRecent $n [list [lrange $mtimeme $j [expr $j+$hunksize-1]]] $recentdef $hunknext"
+				set hunkcode($hunknow) "manReadRecent $n [list [lrange $mtimeme $j [expr {$j+$hunksize-1}]]] $recentdef $hunknext"
 			}
 		}
 	}
 
 	# collect names from directory
+	set cnt 0
 	foreach i $mani($n,dirs) {
-		set dirs $i
-		# suck up corresponding cat dir too, discarding duplicates, in order to combat stray cats
-		if {[regsub {/man([^/]+)$} $i {/cat\1} d2] && [file isdirectory $d2] && [file readable $d2]} {
-			lappend dirs $d2
-		}
-#DEBUG {	puts "  checking $dirs" }
-		set escmen " "
-		foreach j $dirs {
-			cd $j
-			# treat list of names as a string for regsub
-			# all names have trailing space
-			append escmen [glob -nocomplain *] " "
+		if {$manx(canformat)} {
+			# all names start and end with space for regexp patterns
+			cd $i; set men " [glob -nocomplain *] "
+		} else {
+			# preformatted pages only (SGI, Windoze)
+			set men ""
 		}
 
 		# normalize names by stripping volume and compression suffixes
-		# (leave dumb SGI .z suffixes to be stripped by general page normalization)
-		regsub -all {\.(gz|Z) } $escmen " " normalmancat
-
+		# (leave dumb SGI .z suffixes to be stripped by general page normalization -- now I find that SGI uses .Z too in installing freeware, just to top their previous peak of stupidity)
+		# (need while loop in case hits on consecutive names)
+		regsub -all $manx(zregexpl) $men {\1 } men
 		# no Emacs backup files "~" or ".bak", or no "." in name
-		regsub -all " \[^ \]+$manx(bkupregexp) " $normalmancat " " nobkup
-		regsub -all { [^ \.]+ } $nobkup " " goodmancat
+		while {[regsub -all $zbkup $men " " men]} {}
+		while {[regsub -all $znodot $men " " men]} {}
 
 		# would like to normalize section number in name (as for .../man/.../<name>.man), but it's too variable -- ???
-		regsub -all {\.[^\. ]* } $goodmancat " " shortmen
+		regsub -all $zsect $men " " men
+
+		# one last pass to escape Tcl meta characters -- I should think these are rare
+		regsub -all $ztclmeta $men {\\\1} men
+
+
+		# suck up corresponding cat dir too, in case have stray cats
+		set cat ""
+		if {[regsub {/man([^/]+)$} $i {/cat\1} d2] && [file isdirectory $d2] && [file readable $d2]} {
+			cd $d2; set cat " [glob -nocomplain *] "
+			regsub -all $manx(zregexpl) $cat {\1 } cat
+			while {[regsub -all $zbkup $cat " " cat]} {}
+			while {[regsub -all $znodot $cat " " cat]} {}
+			regsub -all $zsect $cat " " cat
+			regsub -all $ztclmeta $cat {\\\1} cat
+			set cat [lsort $cat]
+		}
 
-		# one last pass to escape Tcl meta characters
-		regsub -all {(\{|\}|\[|\]|\")} $shortmen {\\\1} simplemen
 
 		set unique {}
 		set lastman ""
-		foreach k [lsort $simplemen] {
+		set cati 0; set catl [llength $cat]
+		set strays {}
+
+		if {!$manx(canformat)} {
+		    foreach k $cat {if {[regexp {\.} $k]} {lappend manx(mandot) $k}}
+		    set unique $cat
+		} else {
+		    # can't use lsort -unique on concat-enated lists as want to glean stray cats
+		    foreach k [lsort $men] {
+			# check for stray cats
+			while {$cati<$catl && [string compare [set kt [lindex $cat $cati]] $k]==-1} {
+				lappend strays $kt
+				lappend unique $kt
+				if {[regexp {\.} $kt]} {lappend manx(mandot) $kt}
+				incr cati
+			}
+			while {[string equal [lindex $cat $cati] $k]} {incr cati}
+
 			# elsewhere handle multiple pages in same man-cat pair with same name but different suffixes, e.g., printf.3s and printf.3v
-			#DEBUG { puts stderr $k }
-			if {$k==$lastman} continue
-
+			if {[string equal $k $lastman]} continue
 			lappend unique $k
-			# only count entries put into database
-			incr cnt
-
-			if {[string match "*.*" $k]} {lappend manx(mandot) $k}
-
+			if {[regexp {\.} $k]} {lappend manx(mandot) $k}
 			set lastman $k
+		    }
 		}
+
 		set manc($n,$i) $unique
+		if {[llength $strays]} {
+			if {[string equal $manx(stray-warnings) ""]} {set manx(stray-warnings) "Stray cats (formatted pages in .../man/catN without corresponding source in .../man/manN)\n"}
+			append manx(stray-warnings) "$d2\n\t$strays\n"
+		}
+
+		incr cnt [llength $unique]
 	}
 
 	return $cnt
@@ -256,18 +290,18 @@ proc manShowSection {w n} {
 	global bmb
 
 	if {[lsearch $manx(manList) $n]==-1} { manWinstderr $w "Volume $n not found"; return }
-	if $manx(shift) { set manx(shift) 0; set w [manInstantiate] }
+	if {$manx(shift)} { set manx(shift) 0; set w [manInstantiate] }
 	set t $w.show; set wi $w.info
 
 	manNewMode $w section $n; incr stat(section)
-	wm title $w "$manx(title$w): Volume $n"
+#	wm title $w "$manx(title$w): Volume $n"
 	set manx(lastvol$w) $n
 	set manx(hv$w) $n
 	manShortcutsStatus $w
 
 	set head [lindex $manx(manTitleList) [lsearch $manx(manList) $n]]
 
-	if {$mani($n,form)==""} {
+	if {[string equal $mani($n,form) ""]} {
 		cursorBusy
 		manWinstdout $w "Formatting $head ..." 1
 		set mani($n,shortvolname) [manFormatSect $n]
@@ -275,14 +309,14 @@ proc manShowSection {w n} {
 	}
 
 	set info $head
-#	if {$mani($n,update)!=""} { append info "   (last update [recently $mani($n,update)])" }
+#	if {![string equal $mani($n,update) ""]} { append info "   (last update [textmanip::recently $mani($n,update)])" }
 	manWinstdout $w $info
 	manSetSect $w $n
 
 	manTextOpen $w
-#	eval $t insert end $mani($n,form) -- sometimes blows up with glimpse word index
+#	eval $t insert end $mani($n,form) -- sometimes blows up with glimpse word index, grumble
 	foreach {txt tag} $mani($n,form) {$t insert end $txt $tag}
-	$w.search.cnt configure -text "$mani($n,cnt) entries"
+	manLineCnt $w $mani($n,cnt) "entries"
 	manTextClose $w
 
 	manYview $w
@@ -295,12 +329,16 @@ proc manShowSection {w n} {
 	$w.vols configure -text $mani($n,shortvolname); set bmb($w.vols) "manShowSection $w $n"
 	set manx(name$w) $head
 
-	if {$man(hyperclick)=="double"} {set mod "Double-" } { set mod "" }
-	if {$n=="glimpse"} {
-		$t tag bind hyper <${mod}ButtonRelease-1> "+$w.search.s invoke"
+#	if {[string equal $man(hyperclick) "double"]} {set mod "Double-" } else {set mod ""}
+	set mod [expr {[string equal $man(hyperclick) "double"]?"Double-":""}]
+	set ev "<${mod}ButtonRelease-1>"
+#	$t tag bind hyper $ev {}
+#	manHyper $w
+	if {[string equal $n "glimpse"]} {
+		$t tag bind hyper $ev "+if {\[string equal \$manx(glimpse-pattern) \$manx(search,string$w)\]} {$w.search.s invoke}"
 #; catch {$w.sections.m invoke {Collapse all}}"
-	} elseif {$n=="glimpseindex"} {
-		$t tag bind hyper <${mod}ButtonRelease-1> "
+	} elseif {[string equal $n "glimpseindex"]} {
+		$t tag bind hyper $ev "+
 			if {\$manx(hotman$t)!={}} { incr stat(man-hyper); manGlimpse \$manx(hotman$t) -w \$manx(out$w) }
 		"
 	}
@@ -312,7 +350,7 @@ proc manFormatSect {n} {
 
 	set form {}; set cnt 0
 
-	if {$n=="high"} {
+	if {[string equal $n "high"]} {
 		lappend form "\tTime of last annotation\n" {}
 		set lastletter ""; set lastday ""
 		set sortedlist {}
@@ -330,20 +368,20 @@ proc manFormatSect {n} {
 			set sortedlist [lsort -integer -index 1 -decreasing $tuples]
 		}
 		foreach k $sortedlist {
-# || $k=="*"
+# || [string equal $k "*"]
 			foreach {name sec} $k break
 
 			# name
 			if {$manx(highsortby)==0} {
-				set letter [string tolower [string range [file tail $name] 0 0]]
-				if {$letter!=$lastletter} {lappend form "$letter  " h2; set lastletter $letter}
+				set letter [string tolower [string index [file tail $name] 0]]
+				if {![string equal $letter $lastletter]} {lappend form "$letter  " h2; set lastletter $letter}
 			}
 			lappend form $name manref
 
 			# time
-			regexp {([0-9]+:[0-9:]+)*(.*)} [recently $sec] all time day
+			regexp {(\d+:[\d:]+)*(.*)} [textmanip::recently $sec] all time day
 			if {$manx(highsortby)==1} {
-				if {$day==$lastday} {set day ""} else {set lastday $day}
+				if {[string equal $day $lastday]} {set day ""} else {set lastday $day}
 			}
 			if {$sec>0} { lappend form "\t$time$day" i }
 			lappend form "\n" {}
@@ -355,13 +393,13 @@ proc manFormatSect {n} {
 		set mani(high,form) $form
 		return "Highlighted"
 
-	} elseif {$n=="recent"} {
+	} elseif {[string equal $n "recent"]} {
 		set first 1
 		foreach i $manx(newmen) {
 			foreach {vol names} $i {}
-			if {$first} {set first 0} {lappend form "\n\n\n" {}}
+			if {$first} {set first 0} else {lappend form "\n\n\n" {}}
 			if {[set index [lsearch $mani(manList) $vol]]!=-1} {
-				lappend form " Volume $vol, \"[lindex $mani(manTitleList) $index]\", updated at " {} [recently $mani($vol,update)] i "\n\n" {}
+				lappend form " Volume $vol, \"[lindex $mani(manTitleList) $index]\", updated at " {} [textmanip::recently $mani($vol,update)] i "\n\n" {}
 			} else { lappend form $vol {} "\n\n" {}}
 			# yay, tabs not underlined!
 			lappend form [join $names "\t"] manref
@@ -369,19 +407,19 @@ proc manFormatSect {n} {
 		}
 		set mani(recent,cnt) $cnt
 		if {$mani(recent,cnt)==0} {
-			lappend form "There are no manual pages less than $man(recentdays) [plural $man(recentdays) day] old.\n" {}
-			lappend form "You can change the definition of `recent' in Occasionals/Preferences/Misc.\n"
+			lappend form "There are no manual pages less than $man(recentdays) [textmanip::plural $man(recentdays) day] old.\n" {}
+			lappend form "You can change the definition of `recent' in Preferences/Misc.\n"
 		}
 		set mani(recent,form) $form
 		return "Recent"
 
-	} elseif {$n=="census"} {
+	} elseif {[string equal $n "census"]} {
 		lappend form "\tTimes read\tTime last read\n" {}
 
 		# can't use array get because it makes value into sublist
 		set cntlist {}
 		foreach name [array names pagecnt] {lappend cntlist [concat $name $pagecnt($name)]}
-		if ![set cnt [llength $cntlist]] {
+		if {![set cnt [llength $cntlist]]} {
 			lappend form "You haven't seen any pages yet!\n"
 		} else {
 			set lastday ""
@@ -389,9 +427,9 @@ proc manFormatSect {n} {
 			if {$manx(censussortby)==0} {set type "-ascii"; set sortdir "-increasing"}
 			foreach tuple [lsort $sortdir $type -index $manx(censussortby) $cntlist] {
 				foreach {name seencnt lastread} $tuple break
-				regexp {([0-9]+:[0-9:]+)*(.*)} [recently $lastread] all time day
+				regexp {(\d+:[\d:]+)*(.*)} [textmanip::recently $lastread] all time day
 				if {$manx(censussortby)==2} {
-					if {$day==$lastday} {set day ""} else {set lastday $day}
+					if {[string equal $day $lastday]} {set day ""} else {set lastday $day}
 				}
 				lappend form $name manref "\t$seencnt\t" {} "$time$day" i "\n" {}
 			}
@@ -399,19 +437,20 @@ proc manFormatSect {n} {
 		set mani($n,form) $form; set mani($n,cnt) $cnt
 		return [lindex {Alpha Frequency Chrono} $manx(censussortby)]
 
-	} elseif {$n=="glimpseindex"} {
+#	} elseif {[string equal $n "glimpsefreq"]} {
+	} elseif {[string equal $n "glimpseindex"]} {
 		manGlimpseIndexShow
 		return "Index"
 	}
 
-	if {$n=="all"} {set sect $man(manList)} {set sect $n}
+	if {[string equal $n "all"]} {set sect $man(manList)} else {set sect $n}
 	set ltmp {}
 	foreach subvar [manSearchArray $sect] {
 		# can't use lappend, at least directly
 		append ltmp $manc($subvar) " "
 	}
 
-	if {$man(volcol)=="0"} {set sep "   "} {set sep "\t"}
+	if {[string equal $man(volcol) "0"]} {set sep "   "} else {set sep "\t"}
 	set cnt 0
 
 	# specialized version of uniqlist
@@ -419,16 +458,16 @@ proc manFormatSect {n} {
 	set sub {}
 	foreach ir [lsort $ltmp] {
 		# no extensions anymore, just the name root
-		set il [string tolower [string range $ir 0 0]]
+		set il [string tolower [string index $ir 0]]
 
-		if {$pl!=$il && [llength $sub]} {
-# && ($n==3 || ![string match {[A-Z]} [string range $i 0 0]])} {
+		if {![string equal $pl $il] && [llength $sub]} {
+# && ($n==3 || ![string match {[A-Z]} [string index $i 0]])} {
 			lappend form [join $sub "\t"] manref "\n\n" {}
 			set sub {}
 			set pl $il
 		}
 		# within same section $pr!=$ir always, but in (all) can have duplicates
-		if {$pr!=$ir} {lappend sub $ir}
+		if {![string equal $pr $ir]} {lappend sub $ir}
 		set pr $ir
 		incr cnt
 	}
@@ -441,6 +480,11 @@ proc manFormatSect {n} {
 	return "($n)"
 }
 
+proc manSortByTail {a b} {
+	return [string compare -nocase [file tail $a] [file tail $b]]
+}
+
+
 
 # would like to show size of page (# lines, maybe only estimated),
 # but it would take forever to stat every file,
@@ -451,20 +495,20 @@ proc manMakeVolList {{recentok 0}} {
 	set m .vols
 	destroy $m; menu $m -tearoff no -font gui
 
-	if {$man(texinfodir)!=""} {
-		$m add command -label "Texinfo" -command "manTextOpen \$curwin; texiTop $man(texinfodir) \$curwin.show; \$curwin.show tag add volume 1.0 end; manTextClose \$curwin; \$curwin.vols configure -text Texinfo; set bmb(\$curwin.vols) {$m invoke Texinfo}"
+	if {![string equal $man(texinfodir) ""]} {
+		$m add command -label "Texinfo" -command "manTextOpen \$curwin; texiTop \$man(texinfodir) \$curwin.show; \$curwin.show tag add volume 1.0 end; manTextClose \$curwin; \$curwin.vols configure -text Texinfo; set bmb(\$curwin.vols) {$m invoke Texinfo}"
 		#"manShowSection \$curwin texi"
 	}
 
-	if {$man(rfcdir)!="" && [file exists $man(rfcdir)/rfc-index.txt]} {
+	if {![string equal $man(rfcdir) ""] && [file exists [file join $man(rfcdir) "rfc-index.txt"]]} {
 		$m add command -label "Request for Comments (RFC)" -command {
 			manShowText $man(rfcdir)/rfc-index.txt
-			searchboxSearch {^[0-9][0-9][0-9][0-9]} 1 1 rfcxref $curwin.show $curwin
+			searchboxSearch {^\d\d\d\d} 1 1 rfcxref $curwin.show $curwin
 			if {![info exists rfcmap]} {
-				manWinstdout $curwin "Finding RFC directories (done first time only)..."
+				manWinstdout $curwin "Finding RFC directories (required first time only)..."
 				cursorBusy
 				foreach rfc [find $man(rfcdir) {[string match "rfc*.txt" $file]} {$depth<=2}] {
-					if [regexp "$man(rfcdir)(.*/rfc0*(\[0-9]\+).txt)" $rfc all dir rfcnum] {
+					if [regexp "$man(rfcdir)(.*/rfc0*(\\d+).txt)" $rfc all dir rfcnum] {
 						set rfcmap($rfcnum) $dir
 					}
 				}
@@ -480,9 +524,9 @@ proc manMakeVolList {{recentok 0}} {
 	set ctr 0
 	foreach i $manx(manList) j $manx(manTitleList) {
 		set menu $m; set label "($i) $j"
-		if {[lassoc $manx(extravols) $i]!=""} {set label $j} \
-		elseif $man(subvols) {
-			set l1 [string range $i 0 0]
+		if {[llength [lassoc $manx(extravols) $i]]} {set label $j} \
+		elseif {$man(subvols)} {
+			set l1 [string index $i 0]
 			set p [lsearch -exact $manx(manList) $l1]
 			set c [lsearch -glob $manx(manList) "$l1?*"]; if {$c>=$iapropos} {set c -1}
 
@@ -494,7 +538,7 @@ proc manMakeVolList {{recentok 0}} {
 
 				# if that cascade menu doesn't exist yet, create it now
 				# (so submenus need not precede their root)
-				if ![winfo exists $menu] {
+				if {![winfo exists $menu]} {
 					menu $menu -tearoff no
 					$m add cascade -label "($i) [lindex $manx(manTitleList) $p]" -menu $menu
 				}
@@ -502,14 +546,14 @@ proc manMakeVolList {{recentok 0}} {
 		}
 
 		# everybody gets added somewhere, under some name
-		if {$i=="census"} {
+		if {[string equal $i "census"]} {
 			$menu add cascade -label $label -menu [set m2 .vols.seensortby]; menu $m2 -tearoff no
 			foreach {label index} {
 				"sort by frequency" 1   "sort chronologically" 2  "sort alphabetically" 0
 			} {
 				$m2 add command -label $label -command "set mani(census,form) {}; set manx(censussortby) $index; manShowSection \$curwin census; \$curwin.show see 1.0"
 			}
-		} elseif {$i=="high"} {
+		} elseif {[string equal $i "high"]} {
 			$menu add cascade -label $label -menu [set m2 .vols.highsortby]; menu $m2 -tearoff no
 			foreach {label index} {
 				"sort chronologically" 1  "sort alphabetically" 0
@@ -523,7 +567,7 @@ proc manMakeVolList {{recentok 0}} {
 	}
 	if {!$recentok} {$m entryconfigure "Recently*" -state disabled -label "Recently -- Available momentarily"}
 
-	$m entryconfigure "*apropos*" -state disabled
+	catch {$m entryconfigure "*apropos*" -state disabled}
 	catch {$m entryconfigure "*glimpse*" -state disabled}
 
 	foreach win [lmatches ".man*" [winfo children .]] {
@@ -542,7 +586,7 @@ proc manCatClear {} {
 	# doesn't respects settings in Paths menu
 	foreach dir $manx(paths) {
 		# if catman, may be only copy of page (SGI only has formatted)
-		if {[string matches "*/catman*" $dir]} continue
+		if {[string match "*/catman*" $dir]} continue
 
 		# don't complain if can't write
 		# maybe wipes out RCSdiff's too
