@@ -13,12 +13,19 @@ proc manGlimpse {name {opts ""} {w .man}} {
 	set len [llength $name]
 	if {$len>=2} {
 		if {[string match "-*" $name]} {
-			set name [lindex $name end]; set opts [concat $opts [lrange $name 0 [expr $len-1-1]]]
+			set name [lindex $name end]; set opts [concat $opts [lrange $name 0 [expr {$len-1-1}]]]
 		} else {
-			set name [tr $name " \t\n" ";"]
+#			set name [tr $name " \t\n" ";"]
+			set name [tr $name {\s} ";"]
 		}
 	}
-	if {$man(indexglimpse)=="distributed"} {
+	if {[string equal $man(indexglimpse) "distributed"]} {
+		set texindexdir [file join $man(texinfodir) glimpse]
+		if {![string equal $man(texinfodir) ""] && [file readable $texindexdir]} {lappend dirs $texindexdir}
+
+		if {![string equal $man(rfcdir) ""] && [file readable $man(rfcdir)]} {lappend dirs $man(rfcdir)}
+		foreach dir $man(indexalso) { if {[file readable $dir]} {lappend dirs $dir} }
+
 		foreach d $manx(paths) {
 			if {$man($d)} {	lappend dirs $d }
 		}
@@ -35,15 +42,16 @@ proc manGlimpse {name {opts ""} {w .man}} {
 	manGlimpse2 $name $dirs $opts $w
 }
 
+set manx(glimpse-pattern) ""; # shouldn't need to set it here, but just to be safe
 proc manGlimpse2 {name dirs {auxopts ""} {w .man}} {
-	global man manx mani sbx env stat STOP
+	global man manx mani sbx env stat STOP texi
 
-	if $manx(shift) {set manx(shift) 0; set w [manInstantiate]}
+	if {$manx(shift)} {set manx(shift) 0; set w [manInstantiate]}
 	set t $w.show; set wi $w.info
 
 	# set name to search for and name to show
-	if {$name==""} {set name $manx(man$w)}
-	if {$name==""} {
+	if {[string equal $name ""]} {set name $manx(man$w)}
+	if {[string equal $name ""]} {
 		manWinstderr $w "Type in regular expression for full text search"
 		return
 	}
@@ -52,8 +60,8 @@ proc manGlimpse2 {name dirs {auxopts ""} {w .man}} {
 	# set options
 	#set opts "-ly"
 	set opts "-y"
-	if {$man(regexp,case)!=-1 || [string tolower $name]==$name} {append opts "i"}
-	if {$man(maxglimpse)!="none"} {append opts " -L $man(maxglimpse):0:5"}
+	if {$man(regexp,case)!=-1 || [string is lower $name]} {append opts "i"}
+	if {![string equal $man(maxglimpse) "none"]} {append opts " -L $man(maxglimpse):0:5"}
 
 	# kill -w for everybody -- use at your own risk: gotta keep for "perl" and others
 	set g1 "$man(glimpse) $auxopts $opts"
@@ -69,7 +77,7 @@ proc manGlimpse2 {name dirs {auxopts ""} {w .man}} {
 
 	foreach d $dirs {
 		# this error reported at startup, so silently skip over missing .glimpse_* here
-		if ![file readable $d/.glimpse_index] continue
+		if {![file readable [file join $d ".glimpse_index"]]} continue
 DEBUG {puts "index search: $g1 -H $d $name"}
 
 		# would be considerably(?) more efficient if Glimpse could handle a list of directories
@@ -80,7 +88,7 @@ DEBUG {puts "index search: $g1 -H $d $name"}
 			set foundList [concat $foundList [lsort [split $matches "\n"]]]
 		} else {set errorList [concat $errorList [list "error with glimpsing $d:"] [split $info "\n"]]}
 	}
-	set fIndexonly [expr [llength $foundList]>$man(maxglimpseexcerpt)]
+	set fIndexonly [expr {[llength $foundList]>$man(maxglimpseexcerpt)}]
 
 
 	# SECOND SEARCH extracts those matches, if < $man(maxglimpseexcerpt), 
@@ -97,8 +105,8 @@ DEBUG {puts "index search: $g1 -H $d $name"}
 		cursorBusy
 
 		foreach d $dirs {
-			if ![file readable $d/.glimpse_index] continue
-			set glz ""; if {[file readable $d/.glimpse_filters] && [file size $d/.glimpse_filters]>1} {set glz "-z"}
+			if {![file readable [file join $d ".glimpse_index"]]} continue
+			set glz ""; if {[file readable [file join $d ".glimpse_filters"]] && [file size [file join $d ".glimpse_filters"]]>1} {set glz "-z"}
 			manWinstdout $w "Glimpsing for \"$showname\" in $d ..."; update; # not "update idletasks" because want to accept stop requests from keyboard (should change "man" to "STOP" and reprogram so can stop with a click too)
 DEBUG {puts "$g2 -H $d $name"}
 			if {$STOP} {set STOP 0; break}
@@ -118,16 +126,56 @@ DEBUG {puts "$g2 -H $d $name"}
 	foreach errmsg $errorList {lappend foundform "$errmsg\n" i}
 	if {[llength $errorList]} {lappend errmsg "\n\n" {}}
 
+	# Texinfo
+	set texindexdir [file join $man(texinfodir) glimpse]
+	if {[string equal $man(texinfodir) ""] || ![file readable $texindexdir]} {set texindexdir ""}
+	if {![string equal $texindexdir ""]} {
+#		if ![info exists texi(texinfo,paths)] { -- always compute as may have changed
+#			set texi(texinfo,paths) {}
+			texiDatabase $man(texinfodir)
+#		}
+		set texifound {}
+	}
+
+
+	# reformat results: link on file, spaces on hit text, canonicalize Texinfo paths
 	foreach page $foundList {
+		set page [string trimright $page ":"]
+
 		# The following not true?
 		# If there are more subMatchVar's than parenthesized subexpressions within exp, or if a
 		# particular subexpression in exp doesn't match the string (e.g. because it was in a
 		# portion of the expression that wasn't matched), then the corresponding subMatchVar
 		# will be set to ``-1 -1'' if -indices has been specified or to an empty string otherwise.
-		if {$page==""} {
+
+		if {![string equal $texindexdir ""] && [string match [file join $texindexdir "*"] $page]} {
+#puts "considering $page"
+			set mapped ""
+
+			# if exact match on file (including compression suffix, if any), it's a keeper...
+			set mapto [zapZ [file tail $page]]
+#puts "\t$mapto"
+			foreach canon $texi(texinfo,paths) {
+				if {[string match /*/$mapto [zapZ $canon]]} {set mapped $canon; break}
+			}
+			# ... else try to match on dir
+			if {[string equal $mapped ""]} {
+				set mapto [file rootname [file tail [file dirname $page]]]
+#puts "\t$mapto"
+				foreach canon $texi(texinfo,paths) {
+					if {[string match /*/$mapto [file dirname $canon]]} {set mapped $canon; break}
+				}
+			}
+			# you'd better have found it by now
+			if {![string equal $mapped ""] && [lsearch $texifound $mapped]==-1} {lappend texifound [set page $mapped]} else {set page ""}; # ... else continue
+#puts "=> $mapped / $page"
+		}
+
+
+		if {[string equal $page ""]} {
 			# nothing
 		} elseif {[string match "/*" $page]} {
-			lappend foundform "[bolg [string trimright $page :] ~]\n" manref
+			lappend foundform "[bolg $page ~]\n" manref
 			incr found
 		} else {
 			lappend foundform "     $page\n" sc
@@ -147,7 +195,7 @@ DEBUG {puts "$g2 -H $d $name"}
 		set form {}
 		lappend form " Glimpse full text search for \"$name\"\n\n" {}
 
-		if $error {
+		if {$error} {
 			lappend form "Errors while Glimpsing:\n\n" {}
 		}
 
@@ -159,7 +207,7 @@ DEBUG {puts "$g2 -H $d $name"}
 
 		# seed regexp and isearch strings
 #		set manx(search,string$w) [tr [tr [llast $name] ";" ".*"] "," "|"]
-		set manx(search,string$w) [tr [tr [llast $name] ";" "|"] "," "|"]
+		set manx(search,string$w) [set manx(glimpse-pattern) [tr [tr [llast $name] ";" "|"] "," "|"]]
 		set sbx(lastkeys-old$t) [llast $name]
 
 		.vols entryconfigure "*glimpse*" -state normal
@@ -181,58 +229,143 @@ proc manGlimpseIndexShow {} {
 	global man manx mani curwin
 
 	set gi [file join $man(glimpsestrays) ".glimpse_index"]
-	if {$man(indexglimpse)!="unified" || ![file readable $gi] || $mani(glimpseindex,update)>[file mtime $gi]} return
+	if {![string equal $man(indexglimpse) "unified"] || ![file readable $gi] || $mani(glimpseindex,update)>[file mtime $gi]} return
 
-	set fid [open $gi]; set index0 "\n"; append indexglimpse [read $fid]; close $fid
-	regsub -all "\002\[^\n\]+" $indexglimpse "" indexnotrail
-	regsub -all "\[\001-\011\013-\037\]+" $indexnotrail "" indexnoctrl
-	regsub -all "\n\[_-\]+\n" $indexnoctrl "\n" indexnobox
-	regsub -all "\n\[^\n\]\[^\n\]?\[^\n\]?\n" $indexnobox "\n" indexno123; # misses some?
-	regsub -all "\n\[^_a-z\]\[^\n\]*\n" $indexno123 "\n" indexnonoise
+	set fid [open $gi]; set indexglimpse [read $fid]; close $fid
+	regsub -all "\002\[^\n\]+" $indexglimpse "" indexglimpse; # offset into partitions -- also \002.... notrail -- 
+	regsub -all "\[\001-\011\013-\037\]+" $indexglimpse "" indexglimpse; # noctrl
+	# need while [regsub ...] or skip every word following a match
+	while {[regsub -all "\n\[_-\]+\n" $indexglimpse "\n" indexglimpse]} {}; # nobox
+	while {[regsub -all "\n\[^\n\]\[^\n\]?\[^\n\]?\n" $indexglimpse "\n" indexglimpse]} {}; # misses some?  -- no123
+	while {[regsub -all "\n\[^_a-z\]\[^\n\]*\n" $indexglimpse "\n" indexglimpse]} {}; # no noise
 
 	set index {}; set sub {}; set och2 "__"
-	foreach i [lsort $indexnonoise] {
+	foreach i [lsort $indexglimpse] {
 		set ch2 [string range $i 0 1]
-		if {$ch2!=$och2} {lappend index [join $sub "\t"] manref "\n\n" {}; set sub {}; set och2 $ch2}
+		if {![string equal $ch2 $och2]} {lappend index [join $sub "\t"] manref "\n\n" {}; set sub {}; set och2 $ch2}
 		lappend sub $i
 	}
-	if {$sub!=""} {lappend index [join $sub "\t"] manref}
+	if {![string equal $sub ""]} {lappend index [join $sub "\t"] manref}
 
 	set mani(glimpseindex,update) [clock seconds]
 	set mani(glimpseindex,form) $index
-	set mani(glimpseindex,cnt) [llength $indexnonoise]
+	set mani(glimpseindex,cnt) [llength $indexglimpse]
+}
+
+
+set mani(glimpsefreq,update) 0
+proc manGlimpseFreqShow {} {
+	global man manx mani curwin
+
+	set gi [file join $man(glimpsestrays) ".glimpse_index"]
+	set gp [file join $man(glimpsestrays) ".glimpse_partitions"]
+	if {![string equal $man(indexglimpse) "unified"] || ![file readable $gi] || ![file readable $gp] || $mani(glimpseindex,update)>[file mtime $gi]} return
+
+	set mani(glimpsefreq,form) 0
+	set fid [open $gi]
+	while {![eof $fid]} {
+		# assume -b or -o (otherwise file offsets stored in _index)
+		if {![regexp "(\[^\002]+)\002(....)" [gets $fid] all name bo]} continue
+		binary scan $bo I offset
+puts "$name $offset"
+	}
+	close $fid
+	return
+	regsub -all "\002\[^\n\]+" $indexglimpse "" indexglimpse; # offset into partitions -- also \002.... notrail -- 
+	regsub -all "\[\001-\011\013-\037\]+" $indexglimpse "" indexglimpse; # noctrl
+	# need while [regsub ...] or skip every word following a match
+	while {[regsub -all "\n\[_-\]+\n" $indexglimpse "\n" indexglimpse]} {}; # nobox
+	while {[regsub -all "\n\[^\n\]\[^\n\]?\[^\n\]?\n" $indexglimpse "\n" indexglimpse]} {}; # misses some?  -- no123
+	while {[regsub -all "\n\[^_a-z\]\[^\n\]*\n" $indexglimpse "\n" indexglimpse]} {}; # no noise
+
+	set index {}; set sub {}; set och2 "__"
+	foreach i [lsort $indexglimpse] {
+		set ch2 [string range $i 0 1]
+		if {![string equal $ch2 $och2]} {lappend index [join $sub "\t"] manref "\n\n" {}; set sub {}; set och2 $ch2}
+		lappend sub $i
+	}
+	if {![string equal $sub ""]} {lappend index [join $sub "\t"] manref}
+
+	set mani(glimpseindex,update) [clock seconds]
+	set mani(glimpseindex,form) $index
+	set mani(glimpseindex,cnt) [llength $indexglimpse]
 }
 
 
 proc manGlimpseIndex {{w .man}} {
-	global man manx mani stat
+	global man manx mani stat texi
 
 	# may have changed glimpse strays dir since startup
 	set var "manx($man(glimpsestrays),latest)"
-	if ![info exists $var] {set $var 0}
+	if {![info exists $var]} {set $var 0}
 
 	# index over all paths, whether currently on or not
+	set texinfodir $man(texinfodir)
+	if {![string equal $texinfodir ""] && [file writable $texinfodir]} {set texindexdir [file join $texinfodir glimpse]} else {set texinfodir ""}
+#puts "cd $texindexdir"
+
+	set rfcdir $man(rfcdir)
+	if {[string equal $rfcdir ""] || ![file readable $rfcdir]} {set rfcdir ""}
 
 	# pairs of (dest-dir-of-index list-of-dirs-to-index)
-	if {$man(indexglimpse)=="distributed"} {
+	if {[string equal $man(indexglimpse) "distributed"]} {
 		set dirpairs {}
-		if [llength $mani($man(glimpsestrays),dirs)] {
+		if {[llength $mani($man(glimpsestrays),dirs)]} {
 			lappend dirpairs [list $man(glimpsestrays) $mani($man(glimpsestrays),dirs)]
 		}
 		foreach dir $manx(paths) {
 			lappend dirpairs [list $dir $mani($dir,dirs)]
 		}
+		if {![string equal $texinfodir ""]} {lappend dirpairs [list $texindexdir $texindexdir]}
+		if {![string equal $rfcdir ""] && [file writable $rfcdir]} {lappend dirpairs [list $rfcdir $rfcdir]}
+		foreach dir $man(indexalso) { if {[file writable $dir]} {lappend dirpairs [$dir $dir]} }
 	} else {
 		set dirs $mani($man(glimpsestrays),dirs)
 		foreach dir $manx(paths) {
 			set dirs [concat $dirs $mani($dir,dirs)]
 		}
+		if {![string equal $texinfodir ""]} {lappend dirs $texindexdir}
+		if {![string equal $rfcdir ""]} {lappend dirs $rfcdir}
+		foreach dir $man(indexalso) { if {[file readable $dir]} {lappend dirs $dir} }
 		set dirpairs [list [list $man(glimpsestrays) $dirs]]
 	}
 
-	set buildsec [expr [lfirst [time {manGlimpseIndex2 $dirpairs $w}]]/1000000]
+	# Texinfo files
+	if {![string equal $texinfodir ""]} {
+#		if ![info exists texi(texinfo,paths)] { -- always compute as may have changed
+#			set texi(texinfo,paths) {}
+			texiDatabase $man(texinfodir)
+#		}
 
-	if {$buildsec<[expr 60*60]} {set buildfmt "%M:%S"} {set buildfmt "%T"}
+		# so many links unaesthetic, would prefer to add directories to -H, but that would pick up too mcuh extraneous junk(?) (in man page directories, just have man pages).  could postprocess .glimpse_filenames and rebuild .glimpse_filename_index with glimpseindex switch and make texindexdir temporary
+		catch {file mkdir $texindexdir}
+		cd $texindexdir
+		catch { eval file delete [glob *] }; # clean up everybody in case deleted some from dir.tkman...
+		# ... and create new links
+		set texlns {}; set manx($texindexdir,latest) [file mtime [file join $texinfodir "dir.tkman"]]
+		foreach tex $texi(texinfo,paths) {
+			set texdir [file dirname $tex]
+			if {![file readable $texdir]} continue
+			set texlist [glob [file join $texdir "*.texi*"]]
+			set cnt [llength $texlist]
+			foreach texexcept {version gpl} {if {[lsearch -glob $texlist */$texexcept.texi*]!=-1} {incr cnt -1}}
+#puts "$texlist => $cnt"
+			if {$cnt==1} {set makeme $tex; set nameme [file tail $tex]} else {set makeme $texdir; set nameme [file tail $texdir].dir}; # XXX.dir so included in *.*
+			set ln [file tail $makeme];	# file w/ or w/o .gz (keep .gz so .glimpse_filters works), or directory
+#puts "ln -s $makeme $nameme"
+			if {[lsearch $texlns $ln]==-1} {
+				exec ln -s $makeme $nameme; lappend texlns $ln
+				set manx($texindexdir,latest) [max $manx($texindexdir,latest) [file mtime [file join $texinfodir "dir.tkman"]]]
+				if {[string equal $man(indexglimpse) "unified"]} {set $var [max [set $var] $manx($texindexdir,latest)]}
+			}
+		}
+	}
+#puts $dirpairs; exit 0
+
+
+	set buildsec [expr {[lfirst [time {manGlimpseIndex2 $dirpairs $w}]]/1000000}]
+
+	if {$buildsec<[expr 60*60]} {set buildfmt "%M:%S"} else {set buildfmt "%T"}
 	if {$buildsec>30 || $man(time-lastglimpse)==-1} {
 		set man(time-lastglimpse) [clock format $buildsec -format $buildfmt]
 	}
@@ -263,7 +396,7 @@ proc manGlimpseIndex2 {dirpairs {w .man}} {
 	foreach pair $dirpairs {
 		foreach {dir dirs} $pair break
 		$t insert end "Working on $dir" b " ($cur of $cnt), "
-		set dircnt [llength $dirs]; set dirtxt [expr $dircnt==1?"directory":"directories"]
+		set dircnt [llength $dirs]; set dirtxt [expr {$dircnt==1?"directory":"directories"}]
 		$t insert end "$dircnt $dirtxt"
 		$t insert end "\n\n"
 		$t see end; update idletasks
@@ -275,9 +408,9 @@ proc manGlimpseIndex2 {dirpairs {w .man}} {
 		}
 
 		set gzt ".glimpse_filters"
-		set gf "$dir/.glimpse_filenames"
-		set gz "$dir/$gzt"
-		set gfe [expr [llength [glob -nocomplain $dir/.glimpse_{filenames,index}]]==2]
+		set gf [file join $dir ".glimpse_filenames"]
+		set gz [file join $dir $gzt]
+		set gfe [expr {[llength [glob -nocomplain [file join $dir ".glimpse_{filenames,index}"]]]==2}]
 
 
 		# see if index is out of date
@@ -310,32 +443,29 @@ proc manGlimpseIndex2 {dirpairs {w .man}} {
 
 
 		# create .glimpse_exclude to ignore RCS, RCSdiff
-		set gex "$dir/.glimpse_exclude"
-		if ![file exists $gex] {
+		set gex [file join $dir ".glimpse_exclude"]
+		if {![file exists $gex]} {
 			set fid [open $gex "w"]
-			puts $fid {.glimpse_exclude$}
-			puts $fid {~$}
-			puts $fid {.bak$}
-			puts $fid {/RCS$}
-			puts $fid {/RCSdiff$}
+			puts $fid [join {.glimpse_exclude$ ~$ .bak$ /RCS$ /RCSdiff .info .c$ .cc$ .h$ .tex$ .dvi$ .ps$} "\n"]
+			# not /RCSdiff$ => have RCSdiff@90, e.g., nowadays
 			close $fid
 		}
 		# "If a file is in both .glimpse_exclude and .glimpse_include it will be excluded"
 		# "Symbolic links are followed by glimpseindex only if they are specifically included here"
-		set gin "$dir/.glimpse_include"
-		if ![file exists $gin] {
+		set gin [file join $dir ".glimpse_include"]
+		if {![file exists $gin]} {
 			set fid [open $gin "w"]
-			puts $fid "*.*"; # same test for valid page names as elsewhere
+			puts $fid "*.*"; # one or more dots in name.  same test for valid page names as elsewhere -- handles .texi too! -- too liberal in accepting dots in directories and .glimpse_filters suffixes, though, as that can count for the dot, but seems to work well enough in practice
 			close $fid
 		}
 
 
 		# see if .glimpse_filters file needed, and if so make one
 		# (but don't overwrite any existing .glimpse_filters)
-		if ![file exists $gz] {
-			set fcat [expr [lsearch -regexp $dirs {/cat[^/]*$}]!=-1]
+		if {![file exists $gz]} {
+			set fcat [expr {[lsearch -regexp $dirs {/cat[^/]*$}]!=-1}]
 #|/catman/
-			set fhp [expr [lsearch -regexp $dirs {\.Z$}]!=-1]
+			set fhp [expr {[lsearch -regexp $dirs {\.Z$}]!=-1}]
 			set fz 0
 			foreach d $dirs {
 				# cd into directory so get the short file names (important for /usr/man!)
@@ -348,28 +478,30 @@ proc manGlimpseIndex2 {dirpairs {w .man}} {
 			# # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 			# create file according to man(compress) and manx(zglob)  #
 			# # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
-			if $fhp {puts $fid "*.Z/*\tzcat <"}
+			if {$fhp} {puts $fid "*.Z/*\tzcat <"}
 			if {$fz} {
 				set zcat [file tail [lfirst $man(zcat)]]
-				switch -glob -- $zcat {
-					gz* {puts $fid "*.z\t$man(zcat)\n*.Z\t$man(zcat)\n*.gz\t$man(zcat)"}
+#				switch -glob -- $zcat {
+#					gz* {puts $fid "*.z\t$man(zcat)\n*.Z\t$man(zcat)\n*.gz\t$man(zcat)"}
 # would like to do this
 #					gz* {puts $fid "*.{z,Z,gz}\t$man(zcat)"}
-					default {
-						# works for zcat, pcat and (one hopes) anything else to come
-						# (string trimright because of HP "zcat < ")
-						puts $fid "*.$manx(zglob)\t[string trimright $man(zcat) { <}]"
-					}
-				}
+#					bzip2 {puts $fid "*.bz2\tbzip2"}
+#					default {
+#						# works for zcat, pcat and (one hopes) anything else to come
+#						# (string trimright because of HP "zcat < ")
+#						puts $fid "*.$manx(zglob)\t[string trimright $man(zcat) { <}]"
+#					}
+#				}
+				foreach z $man(zlist) {puts $fid "*.$z\t$man(zcat)"}
 			}
 			# strip AFTER decompression
-			if $fcat {puts $fid "*/cat*/*\trman <"}
+			if {$fcat} {puts $fid "*/cat*/*\trman <"}
 			close $fid
 		}
 
 
 		### try to index or re-index directory
-		if [catch {set fid [open "|$man(glimpseindex) -z -H $dir $dirs"]} info] {
+		if {[catch {set fid [open "|$man(glimpseindex) -z -H $dir $dirs"]} info]} {
 			# other problems ... like what?
 DEBUG {puts "error on: $man(glimpseindex) -z -H $dir $dirs]: $info"}
 			$t insert end "$info\n" bi
@@ -381,25 +513,25 @@ DEBUG {puts "$man(glimpseindex) -z -H $dir $dirs"}
 			set blankok 0
 			while {![eof $fid]} {
 				gets $fid line
-				if {![regexp {(^This is)} $line] && ($line!="" || $blankok)} {
+				if {![regexp {(^This is)} $line] && (![string equal $line ""] || $blankok)} {
 					$t insert end "$line\n" tt; $t see end; update idletasks
 					set blankok 1
 				}
 				update idletasks
 			}
-			if [catch {close $fid} info] { $t insert end "ERRORS\n" {indent bi} $info indent2 "\n" }
+			if {[catch {close $fid} info]} { $t insert end "ERRORS\n" {indent bi} $info indent2 "\n" }
 
 			if {[file size $gf]==0} {
 				$t insert end "No files could be indexed.  No full text searching available here.\n" {indent bi}
-				if [file exists $gz] {
+				if {[file exists $gz]} {
 					$t insert end "Try checking your $gzt file in $dir.  If $gzt wasn't created by TkMan, try deleting it and letting TkMan create one of its own.\n" indent
 				}
 			} else {
 				# give glimpse files same permissions as directory
 				catch {
 					file stat $dir dirstat
-					set perm [format "0%o" [expr $dirstat(mode)&0666]]
-					foreach setperm [glob $dir/.glimpse_*] {file attributes $setperm -permissions $perm}
+					set perm [format "0%o" [expr {$dirstat(mode)&0666}]]
+					foreach setperm [glob [file join $dir ".glimpse_*"]] {file attributes $setperm -permissions $perm}
 				}
 			}
 		}
@@ -422,8 +554,8 @@ DEBUG {puts "$man(glimpseindex) -z -H $dir $dirs"}
 
 proc manGlimpseClear {} {
 	global man manx
-	foreach [concat $manx(paths) $man(fsstnddir)] {
+	foreach dir [concat $manx(paths) $man(fsstnddir)] {
 		# zaps .glimpse_filters, which may have been carefully constructed manually
-		catch {eval file delete -force [glob $dir/.glimpse_*]}
+		catch {eval file delete -force [glob [file join $dir ".glimpse_*"]]}
 	}
 }
