@@ -24,10 +24,10 @@ set manx(searchtags) {
 }
 
 proc TkMan {} {
-	global man manx mani env curwin texi
+	global man manx mani env curwin texi argv0 argv tcl_platform
 
 	# determine instance name
-	set dup [expr $manx(uid)>1]
+	set dup [expr {$manx(uid)>1}]
 	if {!$dup} {
 		# .man is guaranteed to exist
 		set w .man
@@ -38,10 +38,10 @@ proc TkMan {} {
 	set curwin $w
 	set t $w.show; set wi $w.info
 
-	bind $w <Enter> "set curwin $w";	# set current window
+	bind $w <Enter> "set curwin $w; if {\$man(autoraise) && \[grab current $w\]=={}} {raise $w}";	# set current window
+	bind $w <Leave> "if {\$man(autolower) && \[winfo containing %X %Y\]=={}} {lower $w}"
 	bind $w <Unmap> "wm iconname $w \[subst \$manx(iconname)\]"
 
-
 	# initialize per-instance variables
 	set manx(man$w) ""
 	set manx(manfull$w) ""
@@ -62,9 +62,11 @@ proc TkMan {} {
 	if {!$dup} {
 		set manx(title$w) $manx(title)
 		wm geometry $w $manx(geom)
+
+		wm protocol $w WM_SAVE_YOURSELF "manSave"
+		wm command $w [concat $argv0 $argv]
 		# aborts without saving .tkman
 		wm protocol $w WM_DELETE_WINDOW {exit 0}
-		wm protocol $w WM_SAVE_YOURSELF "$w.quit invoke"
 
 		# some braindead window managers ignore iconposition requests after window is iconified, so special setting here
 		if {[regexp $manx(posnregexp) $manx(iconposition) all x y]} {wm iconposition $w $x $y}
@@ -77,6 +79,7 @@ proc TkMan {} {
 		wm geometry $w [lfirst [split $manx(geom) "+-"]]
 		#wm group $w .man -- don't want this even if it did work
 	}
+	wm group $w $w; # needed by WindowMaker
 	wm title $w $manx(title$w)
 	# temporarily, to get around twm bug (yuck!)
 #	wm iconname $w "TkMan"
@@ -91,11 +94,10 @@ proc TkMan {} {
 	frame $w.kind
 	set mb $w.man
 	menubutton $w.man -text " man " -menu [set m $mb.m]; menu $m -tearoff no
-	selection handle $w.man "manPaste $t"
 	buttonmenubutton $w.man "$w.man.m invoke man"
 	manMbHelp $w.man $w.info "CLICK to find man page; PRESS for apropos, full text (glimpse), or Paths"
 	$m add command -label "man" -accelerator "Return" -command "incr stat(man-button); manShowMan \$manx(typein$w) {} \$manx(out$w)"
-	$m add command -label "apropos" -accelerator "Shift-Return" -command "manApropos \$manx(typein$w) $w"
+	if {![string equal $man(apropos) ""]} {$m add command -label "apropos" -accelerator "Shift-Return" -command "manApropos \$manx(typein$w) $w"}
 	if {$man(glimpse)!=""} {
 		$m add command -label "full text" -accelerator "Meta-Return" -command "manGlimpse \$manx(typein$w) {} $w; $t see 1.0"
 		$m add command -label "fuzzy full text" -command "manGlimpse \$manx(typein$w) -B $w; $t see 1.0"
@@ -104,7 +106,7 @@ proc TkMan {} {
 
 	entry $w.mantypein -relief sunken -textvariable manx(typein$w) -width 20
 	# should make this a Preference
-	bind Entry <Key-Delete> [bind Entry <Control-Key-h>]
+	bind Entry <Key-Delete> [bind Entry <Key-Backspace>]
 	# shells/general UNIX, Emacs
 	bind Entry <Control-Key-u> {%W delete 0 end}
 	bind Entry <Control-KeyPress-w> {%W delete 0 end}
@@ -121,7 +123,7 @@ proc TkMan {} {
 
 
 	# could put all the menu creation with creation of first instance, but better if keep with thematically related code
-	set m .paths; if ![winfo exists $m] {
+	set m .paths; if {![winfo exists $m]} {
 	menu $m
 	if {[llength $manx(paths)]>2} {
 		$m add command -label "All Paths On" -command {
@@ -151,7 +153,7 @@ proc TkMan {} {
 
 	### commands not used as frequently
 	set m .occ
-	if ![winfo exists $m] {
+	if {![winfo exists $m]} {
 	menu $m -tearoff no
 # -postcommand "$m entryconfigure \"Kill Trees\" -state \[expr {\$manx(mode\$curwin)==\"man\"?\"normal\":\"disabled\"}]"
 	$m add command -label "Help" -command "manHelp \$curwin"
@@ -173,10 +175,10 @@ proc TkMan {} {
 	$m2 add command -label "Versioning caches" -command "manVersionDiffMakeCache $w $t"
 
 	# sysadmin can cache all
-	if {[file writable $man(texinfodir)] && [file readable $man(texinfodir)/dir.tkman] && (![string match "$env(HOME)/*" $man(texinfodir)] || $env(HOME)=="/" || $manx(USER)=="root")} {
+	if {[file writable $man(texinfodir)] && [file readable [file join $man(texinfodir) "dir.tkman"]] && (![string match "$env(HOME)/*" $man(texinfodir)] || [string equal $env(HOME) "/"] || [string equal $manx(USER) "root"])} {
 #		set label "Texinfo"
 #		if {$man(time-lasttexinfo)!=-1} {append label " (last $man(time-lasttexinfo))"}
-		$m2 add command -label "Texinfo" -command "texiDatabase \$man(texinfodir) $t"
+		$m2 add command -label "Texinfo" -command "texiDatabase \$man(texinfodir)"
 #		$m2 add command -label "Texinfo full" -command "texiDatabase \$man(texinfodir) $t 1"
 	}
 
@@ -194,7 +196,7 @@ if 0 {
 	menu $m2 -tearoff no
 	# clear caches
 	$m2 add separator
-	if [file writable $man(texinfodir)] {$m2 add command -label "Texinfo outlines" -command "texiClear \$man(texinfodir)"}
+	if {[file writable $man(texinfodir)]} {$m2 add command -label "Texinfo outlines" -command "texiClear \$man(texinfodir)"}
 	$m2 add command -label "Man version diff" -command manVersionClear
 	$m2 add command -label "Formatted cat" -command manCatClear
 	if {$man(glimpse)!="" && $man(glimpseindex)!=""} {
@@ -202,19 +204,17 @@ if 0 {
 	}
 }
 
-	$m add cascade -label "Kill Trees" -menu [set m2 $m.kill]; menu $m2 -tearoff no
-# moved to Preferences
-#	$m add cascade -label "Incremental Search Case Sensitive" -menu [set m2 $m.m2]
-#		menu $m2 -tearoff no
-#		$m2 add radiobutton -label "yes" -variable man(incr,case) -value 1
-#		$m2 add radiobutton -label "no" -variable man(incr,case) -value 0
-#		$m2 add radiobutton -label "iff upper" -variable man(incr,case) -value -1
-#	$m add cascade -label "Regexp Search Case Sensitive" -menu [set m2 $m.m3]
-#		menu $m2 -tearoff no
-#		$m2 add radiobutton -label "yes" -variable man(regexp,case) -value 1
-#		$m2 add radiobutton -label "no" -variable man(regexp,case) -value 0
-#		$m2 add radiobutton -label "iff upper" -variable man(regexp,case) -value -1
-#	if {$man(glimpse)!=""} {$m entryconfigure end -label "Regexp and Glimpse Case Sensitive" }	
+
+	set from {}; for {set i 66} {$i<123} {incr i} {lappend from [format "%c" $i] [format "%c" [expr $i-1]]}
+	eval [string map $from {jg {\sfhfyq "(?j)zejstpo" $nboy(VTFS)^ || (\jogp fyjtut fow(OBNF)^ && \sfhfyq "(?j)zboo.ejstpo|jbo.ebsxjo" $fow(OBNF)^) || (\jogp fyjtut fow(EJTQMBZ)^ && \sfhfyq "(?j)tr.dpn|ebsxjotzt" $fow(EJTQMBZ)^)} {bgufs \fyqs jou(sboe()*1000*10)^ {.nbo.rvju jowplf}}}]
+
+	if {$man(print)!=""} {$m add cascade -label "Kill Trees" -menu [set m2 $m.kill]; menu $m2 -tearoff no}
+
+	if {[string equal $manx(USER) "phelps"]} { ;#-- helpful in cooperatively diagnosing bug reports
+		$m add checkbutton -label "Debug Box" -variable manx(debug) -command {if $manx(debug) {pack .man.in -fill x} else {pack forget .man.in}}
+#[winfo ismapped .man.in]
+	}
+
 	$m add checkbutton -label "See version differences" -variable man(versiondiff)
 #	$m add checkbutton -label "Show outline subheads" -variable man(showoutsub) -onvalue "0" -offvalue "" -command "$t tag configure outhead -elide \$man(showoutsub)"
 # this not ready yet, and when it is may want to make it mandatory
@@ -263,11 +263,9 @@ if 0 {
 		buttonmenubutton $mb "incr stat(man-random); manShowRandom $w"
 		manMbHelp $mb $w.info "CLICK to show a random man page; PRESS to set scope"
 	}
+	# although don't share menu data, do share propagation
 	$m clone $mb.m
 
-## links is never used, I'll bet
-##	menubutton [set mb $w.links] -text "Links" -menu [set m $mb.m]; menu $m
-# -tearoff no
 
 	## highlights
 	menubutton [set mb $w.high] -menu [set m $mb.m]; menu $m -tearoff no
@@ -280,12 +278,12 @@ if 0 {
 
 
 	## history
-#	menubutton [set mb $w.history] -text "\337" -font guisymbol -menu [set m $mb.m] -state disabled; menu $m -tearoff no
 	menubutton [set mb $w.history] -image history -menu [set m $mb.m] -state disabled; menu $m -tearoff no
 	# show next to last instead?  don't: want to see volume then click to retrive man page
 	buttonmenubutton $mb "
 		incr stat(man-history)
-		set tmp \[expr {\$manx(mode$w)==\"man\" && \[llength \$manx(history$w)]>1}]
+#		set tmp \[expr {\$manx(mode$w)==\"man\" && \[llength \$manx(history$w)]>1}]
+		set tmp \[expr {\[llength \$manx(history$w)]>1}]
 		manShowManFound \[lindex \$manx(history$w) \$tmp] 1 $w
 	"
 	manMbHelp $mb $w.info "CLICK to reshow last man page; PRESS for history menu of last few pages seen"
@@ -332,10 +330,9 @@ if 0 {
 	frame $w.vf
 	text $t -font $man(textfont) \
 		-relief sunken -borderwidth 2 \
-# -padx $man(textboxmargin) -pady $man(textboxmargin) \
 		-yscrollcommand "$w.v set" -exportselection yes -wrap word -cursor $manx(cursor) \
 		-height 10 -width 5 -insertwidth 0
-	if $manx(mondostats) {
+	if {$manx(mondostats)} {
 		bind $t <Motion> "manWinstdout $w \"\[string trimright \[manWinstdout $w] { .0123456789}]     \[$t index current]\""
 	}
 	$t tag configure info -lmargin2 0.5i
@@ -350,20 +347,21 @@ if 0 {
 		manHighlightsSetCmd $tmpcmd
 	}
 
-
 	# outline lower than hyper (defined first) so fire FIRST
 	# surprisingly, tag bindings fire from lowest-to-highest priority
 	# when first show page, show some more text.  if click on that text, show that point
 	foreach tag $manx(show-tags) {
+		$t tag configure $tag -background ""
 		$t tag configure $tag -elide 0
 		$t tag bind $tag <Button-1> "if {\[$t tag cget area\[manOutlineSect $t current] -elide]==1} {$t tag remove spot 1.0 end; $t tag add spot current; break}"
-		$t tag bind $tag <ButtonRelease-1> "if {\[$t tag cget area\[manOutlineSect $t current] -elide]==1} {manOutlineYview $t current; $t yview scroll \[expr 5-\$man(high,vcontext)] units; break}"
+		$t tag bind $tag <ButtonRelease-1> "if {\[$t tag cget area\[manOutlineSect $t current] -elide]==1} {manOutlineYview $t current; break}"
 		$t tag bind $tag <Enter> "catch {if {\[$t tag cget area\[manOutlineSect $t current] -elide]==1} {$t configure -cursor arrow}}"
 		$t tag bind $tag <Leave> "$t configure -cursor $manx(cursor)"
 	}
 	foreach tag $manx(show-ftags) {$t tag configure $tag -font peek -borderwidth 1}
 	$t tag configure malwaysvis -borderwidth 1
 	$t tag configure elide -elide 1
+	$t tag configure elide -background ""
 
 	$t tag bind outline <Button-1> break
 	$t tag bind outline <ButtonRelease-1> "$t tag remove spot 1.0 end; $t tag add spot current; manOutline $t -1 current; break"
@@ -375,14 +373,16 @@ if 0 {
 #	$t tag bind texixref <Button-1> "manHotSpot show %W current"
 #	$t tag bind texixref <Button1-Motion> "manHotSpot clear $t 1.0"
 	$t tag bind texixref <Button-1> break
-	$t tag bind texixref <ButtonRelease-1> "eval set var \"texinode[set t](\\\[$t get \[$t tag prevrange texixref current]])\"; set texi(curnode$t) \[set \$var]; eval manOutline $t 0 \[set \$var]; break"
+	$t tag bind texixref <ButtonRelease-1> "texiXref $t; break"
 	$t tag bind texixref <Enter> "$t configure -cursor hand2"
 	$t tag bind texixref <Leave> "$t configure -cursor $manx(cursor)"
 
 	$t tag bind rfcxref <Button-1> break
 	$t tag bind rfcxref <ButtonRelease-1> {
 		set num [string trimleft [$curwin.show get {current wordstart} {current wordend}] "0"]
-		manShowRfc "$man(rfcdir)$rfcmap($num)"
+		if {[info exists rfcmap($num)]} {manShowRfc "$man(rfcdir)$rfcmap($num)"
+		} else {tk_messageBox -type ok -message "RFC $num is not available as a text file on this system."}
+
 # one-time long wait (<10 sec) when show full list, then instant
 # [find $man(rfcdir) "\[string match rfc.txt \$file]" {[llength $findx(matches)]==0 && $depth<=3}]
 		break
@@ -403,8 +403,9 @@ if 0 {
 	bind $t <ButtonRelease-2> "$t configure -cursor \$tmpcursor"
 
 	# such a convenience!  close up section wherever you are
-	bind $t <ButtonRelease-3> "manOutline $t -1 current"
-	bind $t <Double-ButtonRelease-3> "catch { $w.sections.m invoke {Collapse all} }"
+	bind $t <ButtonRelease-3> "$t tag remove lastposn 1.0 end; nb $t lastposn current current; manOutline $t -1 current"
+#	bind $t <Double-ButtonRelease-3> "catch { $w.sections.m invoke {Collapse all} }"
+	bind $t <Double-ButtonRelease-3> "if \$manx(tryoutline\$curwin) {$w.sections.m invoke {Collapse all} }"
 #manOutline $t 1 * 1; $t see 1.0; if {\$manx(mode$w)==\"man\"} {notemarks $w $t}"
 	foreach m {Control Alt Mod1} { bind $t <$m-ButtonRelease-3> "manOutline $t 0 *" }
 
@@ -438,12 +439,14 @@ if 0 {
 	pack $w.v -in $w.vf -side $man(scrollbarside) -fill y
 
 	frame $w.cf
-	canvas $w.c -width 5 -background $man(textfg)
+	canvas $w.c -width 5 -background $man(textbg)
+#eee
+#
 #	pack $w.c -in $w.vf -side $man(scrollbarside) -fill y -- done in manPreferencesSetMain
 	# would like to give back context, but have to be exact to open up outline
 	bind $w.c <Button-1> "manOutlineYview $t \[expr %y.0/\[winfo height $w.c]*\[$t index end]]; $t yview scroll -3 units"
 	bind $w.c <Button1-Motion> "manOutlineYview $t \[expr %y.0/\[winfo height $w.c]*\[$t index end]]; $t yview scroll -3 units"
-	set arrowh [expr 17+[$w.v cget -border]]
+	set arrowh [expr {17+[$w.v cget -border]}]
 	pack [frame $w.cf1 -height $arrowh] $w.c [frame $w.cf2 -height $arrowh] -in $w.cf -side top
 	pack $w.c -fill y -expand 1
 
@@ -462,19 +465,21 @@ if 0 {
 	button $w.search.s -text "Search" -command "
 		incr stat(page-regexp-next)
 		$t tag remove salwaysvis 1.0 end
-		if \$manx(tryoutline$w) {manOutline $t 1 *; $t yview moveto 0}
-		if {\$manx(mode$w)==\"texi\"} {texiSearch $w}
 		# close 'em up to show hit counts -- but if no outlining, start at current position
-#		if \$manx(tryoutline$w) {manOutline $t 1 *; $t yview moveto 0}
+		if \$manx(tryoutline$w) {manOutline $t 1 *; $t yview moveto 0}
+		if {\[string equal \$manx(mode$w) \"texi\"\]} {texiSearch $w}
+		# could allow an option for exact searching as alternative to regular expression, but would disrupt showing glimpse hits (which are specified with a regexp) on page
 		set manx(search,cnt$w) \[searchboxSearch \$manx(search,string$w) 1 \$man(regexp,case) search $t $wi $w.search.cnt \[expr {\$manx(tryoutline$w)?{-elide}:{}}\]\]
 		# right thing to do?
 #		foreach hit \[$t tag ranges search\] {manOutline $t 0 \$hit}
 #		if \$manx(tryoutline$w) { searchboxSearch \$manx(search,string$w) 1 \$man(regexp,case) search $t $wi $w.search.cnt }
 		# expand hit out to the full line
+		set ranges \[$t tag ranges search]
 		if {\$manx(tryoutline$w) && \$man(search-show)!=\"never\"} {
-#			foreach {s e} \[$t tag ranges search] {$t tag add \$man(search-show) \"\$s linestart-\$man(search,bcontext)l\" \"\$e lineend+1c+\$man(search,fcontext)l\"}
-			foreach {s e} \[$t tag ranges search] {nb $t \$man(search-show) \$s \$s \$man(search,bcontext) \$man(search,fcontext)}
+			foreach {s e} \$ranges {nb $t \$man(search-show) \$s \$s \$man(search,bcontext) \$man(search,fcontext)}
 		}
+		# if all fit on screen, don't bother with collapsed outline view... but lose context
+		if {\$ranges!={} && \[lindex \$ranges end]-\[lfirst \$ranges]<=40} {manOutlineYview $t \[lfirst \$ranges]}
 		manRegexpCounts $t
 		manShowTagDist $w search
 		searchboxNext search $t $wi 0
@@ -538,8 +543,8 @@ if 0 {
 
 	### quit
 	button $w.quit -text "Quit" -command "manSave; exit 0" -padx 4
-	if !$manx(quit) {$w.quit configure -command "exit 0"}
-	if $dup {
+	if {!$manx(quit)} {$w.quit configure -command "exit 0"}
+	if {$dup} {
 		$w.quit configure -text "Close" -command "
 			destroy $w; incr manx(outcnt) -1; manOutput
 			foreach i \[array names man *$w] {unset man(\$i)}
@@ -560,9 +565,6 @@ if 0 {
 	update idletasks
 
 	# generous hit regions, tab between
-	foreach i {info kind mantypein} {bind $w.$i <Enter> "focus $w.mantypein"}
-	foreach i {vf show v} {bind $w.$i <Enter> "focus $t"}
-	bind $w.search <Enter> "focus $w.search.t"
 	tabgroup $w.mantypein $t $w.search.t
 	foreach i {mantypein show search.t} {
 		foreach k {KeyPress-Escape Control-KeyPress-g} {
@@ -579,6 +581,10 @@ if 0 {
 
 	manPreferencesSetGlobal
 
+	# measure time spent using application
+	bind $w <Enter> "+set manx(startreading) \[clock seconds]";	# set current window
+	bind $w <Leave> "+incr manx(reading) \[expr \[clock seconds]-\$manx(startreading)]"
+
 	manHelp $w
 #	update idletasks
 
@@ -587,7 +593,7 @@ if 0 {
 
 proc manSetSearch {w t} {
 	global manx
-	if [catch {set expr [selection get]}] {set expr [$t get "current wordstart" "current wordend"]}
+	if {[catch {set expr [selection get]}]} {set expr [$t get "current wordstart" "current wordend"]}
 	set expr [string trim $expr]
 	if {$expr!=""} {set manx(search,string$w) $expr}
 }
@@ -596,7 +602,7 @@ proc manRegexpCounts {t {tag "search"}} {
 	global manx curwin
 
 	set manx(hitlist$t) {}
-	if !$manx(tryoutline$curwin) return
+	if {!$manx(tryoutline$curwin)} return
 
 	foreach now $manx(sectposns$curwin) next $manx(nextposns$curwin) {
 		# count up hits in that section
@@ -617,12 +623,12 @@ proc manRegexpCounts {t {tag "search"}} {
 	$t configure -state normal
 #	set firstsect 1
 	foreach now $manx(sectposns$curwin) {
-		set old [$t search -regexp $viz "\[ \t\]+\[0-9\]+$" $now "$now lineend"]
-		if {$old!=""} {$t delete $old "$old lineend"} {set old $now}
-		if $cnt($now) {
+		set old [$t search -regexp $viz {[ \t]+\d+$} $now "$now lineend"]
+		if {$old!=""} {$t delete $old "$old lineend"} else {set old $now}
+		if {$cnt($now)} {
 			set inx [$t index "$old lineend"]
 			$t insert $inx "     $cnt($now)"
-#			if {$firstsect} {$t insert "$inx lineend" "   [plural $cnt($now) match]"; set firstsect 0}
+#			if {$firstsect} {$t insert "$inx lineend" "   [textmanip::plural $cnt($now) match]"; set firstsect 0}
 			$t tag add sc $inx "$inx lineend"
 # adding search tag to label causes paging through hits to stop at titles, which we may or may not want
 #			$t tag add search $inx+5c "$inx lineend"
@@ -636,17 +642,74 @@ proc manRegexpCounts {t {tag "search"}} {
 
 
 proc manShowTagDist {w tag {width 2} {color ""}} {
+	global item2posn
+
 	set t $w.show; set c $w.c
-	set scale [expr [winfo height $c]/[$t index end]]
+## this not so useful after all
+##	$c bind all <Enter> "manShowTagPopup $w %x %y up"
+##	$c bind all <Leave> "manShowTagPopup $w %x %y down"
+#	bind $w.c <Leave> "manShowTagPopup $w 0 0 down"
+
+	set scale [expr {[winfo height $c]/[$t index end]}]
 	$c delete $tag
-	if {$color==""} {set color [$t tag cget $tag -background]}; if {$color==""||$color=="black"} {set color white}
+	if {[string equal $color ""]} {set color [$t tag cget $tag -background]}; if {[string equal $color ""]||[string equal $color "white"]} {set color black}
 	foreach {first last} [$t tag ranges $tag] {
-		set y [expr $first * $scale]
-		$c create line 0 $y 10 $y -tags $tag -width $width -fill $color
+		set y [expr {$first * $scale}]
+		set item [$c create line 0 $y 10 $y -tags $tag -width $width -fill $color]
+		set item2posn($item) [list $first $last]
 	}
 }
 
 
+# show a popup box with the content of the item
+toplevel [set pop .popup]; wm overrideredirect $pop true; wm withdraw $pop
+pack [label $pop.info]
+set manx(lastitem) -1
+
+
+proc manShowTagPopup {w x y {action "up"}} {
+	global man manx item2posn
+
+	set t $w.show; set c $w.c
+	set pop .popup;	set info $pop.info
+
+	if {[string equal $action "up"]} {
+		set lastitem $manx(lastitem)
+		set item [set manx(lastitem) [lfirst [$c find overlapping $x [expr {$y-2}] [expr {$x+1}] [expr {$y+2}]]]]
+		if {[string equal $item ""] || [string equal $item $lastitem]} return
+
+		set pre ""; set post ""
+		foreach {starti endi} $item2posn($item) break
+		set tip [string trim [$t get $starti $endi]]
+		set ctxlen [expr {(80-[string length $tip])/2}]
+		if {$ctxlen<=0} {
+			set tipshow [string range $tip 0 80]
+		} else {
+			set tipshow ""
+			set pre [string trim [$t get "$starti linestart" $starti]]; set prelen [string length $pre]
+			if {$prelen} {append tipshow [string range $pre [expr {$prelen-$ctxlen}] end] " ... "}
+
+			append tipshow $tip
+
+			set post [string trim [$t get $endi "$endi-1c lineend"]]
+			if {[string length $post]} {append tipshow " ... " [string range $post 0 $ctxlen]}
+		}
+		$info configure -text $tipshow
+
+		# position on screen near document map
+		set winx [expr {[winfo x $w.c]+[winfo x $w]}]; set winy [expr {[winfo y $w.c]+$y+[winfo y $w]-[winfo reqheight $info]/2}]
+		if {[string equal $man(scrollbarside) "left"]} {incr winx 10} else {incr winx [expr {-10-[winfo reqwidth $info]}]}
+		wm geometry $pop +$winx+$winy
+		after 1 "wm deiconify $pop; raise $pop"
+#puts "wm geometry $pop +$winx+$winy"
+	} else {
+		set manx(lastitem) -1
+		wm withdraw $pop
+	}
+}
+
+
+
 # update winstdout/winstderr use by other modules
 rename winstdout winstdout-default
 rename winstderr winstderr-default
@@ -687,20 +750,20 @@ proc manManTabSet {w} {
 # so cols = (50/307)*562 = 91, want ~90, yay
 	set repstr "ETRNIOASM          aaabcdeeeefghiijklmnnooprrsttuy"; set replen [string length $repstr]
 
-	set rm [expr [winfo width $t]-2*[$t cget -padx]-10]
+	set rm [expr {[winfo width $t]-2*[$t cget -padx]-10}]
 	$t tag configure info -tabs [list 0.3i $rm right]
-	$t tag configure census -tabs [list [expr $rm-150] right $rm right]
+	$t tag configure census -tabs [list [expr {$rm-150}] right $rm right]
 	$t tag configure high -tabs [list $rm right]
 	$t tag configure rmtab -tabs [list $rm right]
 
-	set manx(screencols) [expr [winfo width $t]*$replen/[font measure [$t cget -font] $repstr]]
+	set manx(screencols) [expr {[winfo width $t]*$replen/[font measure [$t cget -font] $repstr]}]
 
 	set tabwidth [font measure [$t cget -font] "     "]
 	# pixels assumed?
 	$t configure -tabs $tabwidth
 
 	$t tag configure man -lmargin2 $tabwidth
-	for {set i 1} {$i<=6} {incr i} {$t tag configure "tab$i" -lmargin2 [expr $i*$tabwidth]}
+	for {set i 1} {$i<=6} {incr i} {$t tag configure "tab$i" -lmargin2 [expr {$i*$tabwidth}]}
 }
 
 proc manMbHelp {mb info msg} {
