@@ -1,8 +1,11 @@
 #--------------------------------------------------
 #
 # Highlights
-#   could have other annotation types, like in situ text,
-#   but not worth it.  Put this effort into Multivalent
+#   COULD...
+#		have other annotation types, like in situ text
+#		just attach/clear highlights for current section, rather than entire document
+#			That way, if have annotations that aren't Notemarks, don't have to fault in
+#   Put this effort into Multivalent
 #
 #--------------------------------------------------
 
@@ -14,8 +17,8 @@ proc manHighlightsSetCmd {{incmd add}} {
 	global manx curwin bmb
 	set w $curwin; # or, upvar #0 curwin w
 	set wh $w.high
-	set txt "Hi"; if {$incmd=="add"} {set txt "+"} elseif {$incmd=="remove"} {set txt "-"}
-	set cmd "add"; if {$incmd=="remove"} {set cmd "remove"}
+	set txt "Hi"; if {[string equal $incmd "add"]} {set txt "+"} elseif {[string equal $incmd "remove"]} {set txt "-"}
+	set cmd "add"; if {[string equal $incmd "remove"]} {set cmd "remove"}
 	$wh configure -text $txt; set bmb($wh) "manHighlights $w $cmd"
 }
 
@@ -25,13 +28,14 @@ proc manHighlights {w {cmd update} {auto 0}} {
 	set t $w.show
 	set status ""
 	set res ""
+	set rele {([\d.]+)/(\d+)\.(\d+)}
 
 	# get/save tags
 	set f $manx(manfull$w)
 #	if [string match <* $f] {set f [string range $f 1 end]}
 	# canonical file name
-	if ![catch {set sf [file readlink $f]}] {
-		if [string match /* $sf] {
+	if {![catch {set sf [file readlink $f]}]} {
+		if {[string match /* $sf]} {
 			set f $sf
 		} else {
 			set f [file dirname $f]
@@ -51,16 +55,16 @@ proc manHighlights {w {cmd update} {auto 0}} {
 	set var high($normalf)
 
 	# try to recover if page moved
-	if {$normalf!="" && ![info exists $var]} {
+	if {![string equal $normalf ""] && ![info exists $var]} {
 		set movelist {}
 		set tail [file tail $normalf]
 		foreach hi [array names high] {
-			if {$tail==[file tail $hi]} {lappend movelist $hi}
+			if {[string equal $tail [file tail $hi]]} {lappend movelist $hi}
 		}
 		foreach hi $movelist {
 			if {[lsearch $manx(highdontask) $hi]!=-1} continue
 			if {[catch {glob $hi$manx(zglob)}]} {
-				if {[tk_messageBox -title "Moved Highlight?" -message "It appears that the highlighted page formerly at\n   $hi\nhas moved to\n   $normalf\nMove highlights too?" -icon question -type okcancel]=="ok"} {
+				if {[string equal [tk_messageBox -title "Moved Highlight?" -message "It appears that the highlighted page formerly at\n   $hi\nhas moved to\n   $normalf\nMove highlights too?" -icon question -type okcancel] "ok"]} {
 					set $var $high($hi); unset high($hi)
 					incr stat(high-carry)
 				} else {lappend manx(highdontask) $hi}
@@ -70,16 +74,16 @@ proc manHighlights {w {cmd update} {auto 0}} {
 	}
 
 
-	if {$cmd=="add" || $cmd=="remove"} {
+	if {[regexp "add|remove" $cmd]} {
 		if {![llength [$t tag nextrange sel 1.0]]} {
 			set errmsg "Select a range of "
-			if {$cmd=="add"} {append errmsg "characters to highlight"} {append errmsg "highlighted characters to unhighlight"}
+			if {[string equal $cmd "add"]} {append errmsg "characters to highlight"} else {append errmsg "highlighted characters to unhighlight"}
 
 			manWinstderr $w $errmsg
 			return
 		}
 		$t tag $cmd highlight sel.first sel.last
-		if {$cmd=="add"} {incr stat(page-highlight-add)} {incr stat(page-highlight-sub)}
+		if {[string equal $cmd "add"]} {incr stat(page-highlight-add)} else {incr stat(page-highlight-sub)}
 		set mani(high,form) {}
 		selection clear $t
 		set cmd "update"
@@ -88,14 +92,14 @@ proc manHighlights {w {cmd update} {auto 0}} {
 #    not going to be switching between seeing and not seeing all the time,
 #    and in the absence of switching, *want* default behavior!
 #    when do switch or update page (an infrequent happening), natural robustness carries the day
-# elseif {$cmd=="save"} {
+# elseif {[string equal $cmd "save"]} {
 #		foreach {s e} [lreverse [$t tag ranges diffd] 2] {$t delete $s $e}
 #		set cmd "update"
 #	}
 
 
 	set tags ""
-	if {$cmd=="update"} {
+	if {[string equal $cmd "update"]} {
 		# new style annotations store date (latest) annotation made
 		set tags [clock seconds]
 		# save some context with tag in hopes of reattaching if the man page changes 
@@ -124,18 +128,30 @@ proc manHighlights {w {cmd update} {auto 0}} {
 				foreach {first firsttxt predelta fhooklen} $ftuple break
 				foreach {ldelta lasttxt postdelta lhooklen} $ltuple break
 
+				# starting position can be relative to section (end is relative to start already)
+				if {[regexp $rele $first all basenum relline charoff secttitle]} {
+#puts "*** decoding baserel $first = js$basenum + $relline l + $charoff c"
+# should have section name as well, but fix this in Multivalent
+# TO DO recovery procedures of section doesn't exist anymore (check sectposns): try supersections if any, faulting in Texinfo along the way
+					set basesect "js$basenum"
+					if {[lsearch $manx(sectposns$w) $basesect]!=-1} {
+						set first [$t index "$basesect linestart+${relline}l+${charoff}c"]
+						if {[string equal $manx(mode$w) "texi"]} {texiFault $t $basesect}
+					}
+				}
+
 				set new [manHighlightAttach $t  $first $firsttxt $predelta $fhooklen   $ldelta $lasttxt $postdelta $lhooklen]
 				foreach {status firstnew ldeltanew} $new break
-				if {$status=="LOSE"} {
+				if {[string equal $status "LOSE"]} {
 					incr stat(high-lose)
-					append losertxt "[string range $firsttxt 0 [expr $predelta-1]] / [string range $firsttxt $predelta end] ($first)   ...   [string range $lasttxt 0 [expr [string length $lasttxt]-$postdelta]] / [string range $lasttxt [expr [string length $lasttxt]-$postdelta+1] end] (+$ldelta)\n"
+					append losertxt "[string range $firsttxt 0 [expr {$predelta-1}]] / [string range $firsttxt $predelta end] ($first)   ...   [string range $lasttxt 0 [expr {[string length $lasttxt]-$postdelta}]] / [string range $lasttxt [expr {[string length $lasttxt]-$postdelta+1}] end] (+$ldelta)\n"
 					append res ", lost one"
 				} elseif {$firstnew!=$first || $ldeltanew!=$ldelta} {
 					# had to move one, save repositioned information
 					incr stat(high-move)
 					eval lappend newtags [manHighCompose $t $firstnew "$firstnew+${ldeltanew}c"]
 					# dicey move
-					if {$status=="DICEY"} { set dicey 1; append res ", dicey move" }
+					if {[string equal $status "DICEY"]} { set dicey 1; append res ", dicey move" }
 				} else {
 					incr stat(high-exact)
 					# old info is still good
@@ -147,14 +163,14 @@ proc manHighlights {w {cmd update} {auto 0}} {
 			set warningtxt ""
 
 			# report losers at bottom
-			if {$losertxt!=""} {
+			if {![string equal $losertxt ""]} {
 				manTextPlug $t end "\n\n\nCouldn't attach these highlights:\n" b $losertxt {} "\n"
 				append warningtxt "Some highlights could not be repositioned.  See the bottom of the page for a list.  They will be forgotten unless they are reapplied manually now.   "
 			}
 			if {$dicey} {
 				append warningtxt "Some highlights have moved considerably and may not have been repositioned correctly.  You may want to verify them now.   "
 			}
-			if {$warningtxt!="" && !$auto} {
+			if {![string equal $warningtxt ""] && !$auto} {
 				tk_messageBox -title "Warning" -message $warningtxt -icon warning -type ok
 			}
 
@@ -170,7 +186,7 @@ proc manHighlights {w {cmd update} {auto 0}} {
 				append res ", OK"
 			} else {
 				# old style highlights lose
-				if {!$auto && [tk_messageBox -title "Warning" -message "Highlights out of date for $f.  Delete them?" -icon question -type yesno]=="no"} {
+				if {!$auto && [string equal [tk_messageBox -title "Warning" -message "Highlights out of date for $f.  Delete them?" -icon question -type yesno] "no"]} {
 					set $var [set tags "[file mtime $f] [lrange [set $var] 1 end]"]
 				}
 				append res ", out of date"
@@ -194,11 +210,15 @@ proc manHighlights {w {cmd update} {auto 0}} {
 	$m delete 0 last
 
 	foreach {first last} [lrange $tags 1 end] {
-		if {[llength $first]>1} { set first [lfirst $first]; set last "$first+[lfirst $last]c" }
+		if {[llength $first]>1} {
+			set first [lfirst $first]
+			if {[regexp $rele $first all basenum relline charoff secttitle]} {set first [$t index "js$basenum linestart+${relline}l+${charoff}c"]}
+			set last "$first+[lfirst $last]c"
+		}
 		$t tag add highlight $first $last
 
 		# show likely relevant information
-		if {$manx(tryoutline$w) && $man(highlight-show)!="never"} {nb $t $man(highlight-show) $first $last}
+		if {$manx(tryoutline$w) && ![string equal $man(highlight-show) "never"]} {nb $t $man(highlight-show) $first $last}
 
 		if {$auto} { $t yview -pickplace $last; update idletasks; after 1000 }
 		set label \
@@ -206,10 +226,10 @@ proc manHighlights {w {cmd update} {auto 0}} {
 		$m add command -label $label \
 			-command "incr stat(page-highlight-go); manOutlineYview $t $first; $t yview scroll \[expr 5-\$man(high,vcontext)] units"
 	}
-	manShowTagDist $w highlight
+	manShowTagDist $w highlight 3
 
 	# propagate highlight information to section headers, if highlights not always visible
-	if {$manx(tryoutline$w) && $man(highlight-show)!="halwaysvis"} {
+	if {$manx(tryoutline$w) && ![string equal $man(highlight-show) "halwaysvis"]} {
 #($manx(subsect-show) => always for man, never for Texinfo
 		foreach now $manx(sectposns$w) next $manx(nextposns$w) {
 			if {[$t tag nextrange highlight $now $next-1l]!=""} {
@@ -232,68 +252,6 @@ proc manHighlights {w {cmd update} {auto 0}} {
 }
 
 
-# update highlights: old to new, throw out nonexistant files
-proc manHighlightsUpdate {{w .man}} {
-	global high mani manx
-
-	if ![array size high] return
-
-	set t $w.show
-
-	# do you need to update your highlights?
-	# give opportunity iff no new style highlights, so most people only asked once
-	set highup 1
-	foreach i [array names high] {
-		if [llength [lsecond $high($i)]]>1 { set highup 0; break }
-	}
-	if {!$highup || [tk_messageBox -title "Update TkMan Highlights?" -message "Do you want to update your [array size high] highlighted pages to use new style highlights that are robust to changes in the man page, automatically and in batch now?  (Otherwise they can be updated manually one by one at any time.)" -icon question -type yesno -default yes]=="no"} {
-		return
-	}
-
-
-	wm deiconify $w
-	manShowSection $w high
-
-	rename manHighlights manHighlightsX
-	proc manHighlights {args} {}
-
-	set newform "The results below will become permanent unless you exit via \"Occasionals / Quit, don't update $manx(startup-short)\"\n\n\n"
-
-	foreach man [array names high] {
-		append newform "$man\t"
-
-		if {[llength [lsecond $high($man)]]>1} { append newform "new style\n"; continue }
-
-		# position old ones on spaces
-		set manx(normalize) ""
-		set stat [manShowMan $man]; update idletasks
-		set manx(normalize) "-N"
-#puts "|$stat|"
-		if {$stat==""} {
-			catch {unset high($man)}
-			set r "doesn't exist"
-# all pages supplied as full paths
-#		} elseif {[string match "ERROR*" $man]} {
-#			#catch {unset high($man)}
-#			set r "not found"
-		} else {
-			set r [manHighlightsX $w get 1]
-			# flush after call that resets highlights
-			update
-
-			$t yview 0
-		}
-
-		append newform "$r\n"
-	}
-
-	rename manHighlights {}
-	rename manHighlightsX manHighlights
-
-	set mani(high,form) $newform
-	manShowSection $w high
-}
-
 
 # compose highlight data record from region of text
 # want excerpt of text 
@@ -304,6 +262,8 @@ proc manHighlightsUpdate {{w .man}} {
 # when/if search across lines, hook-length worthless
 
 proc manHighCompose {t first last} {
+	global manx
+
 	set excerptmax 30; set hookmax 20
 
 	scan [$t index $first] "%d.%d" fline fchar
@@ -313,10 +273,11 @@ proc manHighCompose {t first last} {
 DEBUG {puts "EXCERPTING first=$first, last=$last, rlen=$rlen, elen=$elen"}
 
 	# compute start 
-	scan [$t index [set fsi "$first linestart"]] "%d.%d" junk fstartchar
+	set fsi "$first linestart"
+#	scan [$t index [set fsi "$first linestart"]] "%d.%d" junk fstartchar
 	scan [$t index [set fei "$first lineend"]] "%d.%d" junk fendchar
-	set exhooklen [min $elen [expr $fendchar-$fchar+1]]
-DEBUG {puts "first\tfstartchar=$fstartchar, fendchar=$fendchar, exhooklen = $exhooklen"}
+	set exhooklen [min $elen [expr {$fendchar-$fchar+1}]]
+DEBUG {puts "first\tfstartchar=0, fendchar=$fendchar, exhooklen = $exhooklen"}
 	if {$exhooklen>=$hookmax} {
 		# excerpted characters form substantial enough hook
 		set hooklen [string length [manHighNormalize [$t get $first $first+${exhooklen}c]]]
@@ -326,15 +287,15 @@ DEBUG {puts "first\tfstartchar=$fstartchar, fendchar=$fendchar, exhooklen = $exh
 		# augment excerpt if possible, at start only (for now?)
 #puts "augmented"
 		# when/if search across lines, don't be limited by start of line, end of line
-		set prei "$first-[expr $hookmax-$exhooklen]c"; if [$t compare $prei < $fsi] { set prei $fsi }
+		set prei "$first-[expr {$hookmax-$exhooklen}]c"; if {[$t compare $prei < $fsi]} {set prei $fsi}
 		set excerpttxt [manHighNormalize [$t get $prei $first+${elen}c]]
-		set posti "$first+${elen}c"; if [$t compare $posti > $fei] { set posti $fei }
+		set posti "$first+${elen}c"; if {[$t compare $posti > $fei]} {set posti $fei}
 		set hooklen [string length [manHighNormalize [$t get $prei $posti]]]
-		set prelen [expr $hooklen-[string length [manHighNormalize [$t get $first $posti]]]]
+		set prelen [expr {$hooklen-[string length [manHighNormalize [$t get $first $posti]]]}]
 	}
 DEBUG {puts "|$excerpttxt|, $prelen, $hooklen"}
-	set firsttag [list $first $excerpttxt $prelen $hooklen]
 
+	set firsttag [list [manPosn2OutnOff $t $first] $excerpttxt $prelen $hooklen]
 
 	# in updating from old to new style, sometimes can get empty line
 	if {!$hooklen} { return "" }
@@ -343,7 +304,7 @@ DEBUG {puts "|$excerpttxt|, $prelen, $hooklen"}
 	# compute end
 	scan [$t index [set esi "$last linestart"]] "%d.%d" junk lstartchar
 	scan [$t index [set eei "$last lineend"]] "%d.%d" junk lendchar
-	set exhooklen [min $elen [expr $lchar-$lstartchar+1]]
+	set exhooklen [min $elen [expr {$lchar-$lstartchar+1}]]
 DEBUG {puts "end\tlstartchar=$lstartchar, lendchar=$lendchar, exhooklen = $exhooklen"}
 	if {$exhooklen>=$hookmax} {
 		# excerpt characters form substantial enough hook
@@ -354,11 +315,11 @@ DEBUG {puts "end\tlstartchar=$lstartchar, lendchar=$lendchar, exhooklen = $exhoo
 		# augment excerpt if possible
 #puts "augmented"
 		# when/if search across lines, don't be limited by start of line, end of line
-		set posti "$last+[expr $hookmax-$exhooklen]c"; if [$t compare $posti > $eei] { set posti $eei }
+		set posti "$last+[expr {$hookmax-$exhooklen}]c"; if {[$t compare $posti > $eei]} {set posti $eei}
 		set excerpttxt [manHighNormalize [$t get $last-${elen}c $posti]]
-		set prei "$last-${elen}c"; if [$t compare $prei < $esi] { set prei $esi }
+		set prei "$last-${elen}c"; if {[$t compare $prei < $esi]} {set prei $esi}
 		set hooklen [string length [manHighNormalize [$t get $prei $posti]]]
-		set postlen [expr $hooklen-[string length [manHighNormalize [$t get $prei $last]]]]
+		set postlen [expr {$hooklen-[string length [manHighNormalize [$t get $prei $last]]]}]
 	}
 	set lasttag [list $rlen $excerpttxt $postlen $hooklen]
 DEBUG {puts "|$excerpttxt|, $hooklen, $postlen"}
@@ -371,17 +332,16 @@ DEBUG {puts "|$excerpttxt|, $hooklen, $postlen"}
 # essential for searching across reformats, but also good for storing in ~/.tkman
 
 proc manHighNormalize {raw {maxlen 0}} {
-	set ws "\[\t\n \]"
 	set new [string trim $raw]
 
 	# zap changebars
 	regsub "\\|+\n" $new "\n" new
 	#regsub -all "\n\\|" $new "\n" new
-	regsub "^\\|+$ws" $new "\n" new
+	regsub {^\|+\s} $new "\n" new
 
 	# linebreaks (hyphens and whitespace) ignored and word spacing ignored
 	regsub -all -- "-\n" $new "\n" new
-	regsub -all "$ws+" $new " " new
+	regsub -all {\s+} $new " " new
 
 	if {$maxlen} { set new [string range $new 0 $maxlen] }
 
@@ -390,7 +350,8 @@ proc manHighNormalize {raw {maxlen 0}} {
 
 proc manHighRegexp {normal} {
 	set regexp [stringregexpesc $normal]
-	regsub -all "\[\t\n \]+" $regexp "\[\t\n |-\]*" regexp
+	# ok to match change bar and hyphen too
+	regsub -all {\s+} $regexp {[\s|-]*} regexp
 	return $regexp
 }
 
@@ -402,17 +363,17 @@ proc manHighlightAttach {t first firsttxt predelta fhooklen  ldelta lasttxt post
 
 	if {!$fhooklen} { set fhooktxt $firsttxt } else {
 		set len [string length $firsttxt]
-		set fhooktxt [string range $firsttxt 0 [expr $fhooklen-1]]
+		set fhooktxt [string range $firsttxt 0 [expr {$fhooklen-1}]]
 		set fextxt [string range $firsttxt $predelta end]
-		set fpretxt [string range $firsttxt 0 [expr $predelta-1]]
+		set fpretxt [string range $firsttxt 0 [expr {$predelta-1}]]
 #puts "fhooktxt=|$fhooktxt|, fextxt=|$fextxt|, fpretxt=|$fpretxt|"
 	}
 	if {!$lhooklen} { set lhooktxt $lasttxt } else {
 		set len [string length $lasttxt]
-		set lhooktxt [string range $lasttxt [expr $len-$lhooklen] end]
-		set lextxt [string range $lasttxt 0 [expr $len-$postdelta-1]]
-		set lhookextxt [string range $lhooktxt 0 [expr [string length $lhooktxt]-$postdelta-1]]
-		set lposttxt [string range $lasttxt [expr $len-$postdelta] end]
+		set lhooktxt [string range $lasttxt [expr {$len-$lhooklen}] end]
+		set lextxt [string range $lasttxt 0 [expr {$len-$postdelta-1}]]
+		set lhookextxt [string range $lhooktxt 0 [expr {[string length $lhooktxt]-$postdelta-1}]]
+		set lposttxt [string range $lasttxt [expr {$len-$postdelta}] end]
 #puts "lhooktxt=|$lhooktxt| / |$lhookextxt|, lextxt=|$lextxt|, lposttxt=|$lposttxt|"
 	}
 
@@ -421,7 +382,7 @@ proc manHighlightAttach {t first firsttxt predelta fhooklen  ldelta lasttxt post
 
 	### attach start of range
 
-	if [$t compare $first >= end] { set first [$t index end-1l] }
+	if {[$t compare $first >= end]} { set first [$t index end-1l] }
 	set flen [string length $fhooktxt]
 	set fpt ""
 
@@ -433,22 +394,22 @@ proc manHighlightAttach {t first firsttxt predelta fhooklen  ldelta lasttxt post
 	# Tk doesn't search across lines!
 	set ffw [$t search -forwards -regexp $viz $fregexp $first end]
 	set fbk [$t search -backwards -regexp $viz $fregexp $first 1.0]
-	if {$ffw=="" && $fbk==""} {
+	if {[string equal $ffw ""] && [string equal $fbk ""]} {
 		# nothing yet
-	} elseif {$ffw==""} {
+	} elseif {[string equal $ffw ""]} {
 		set fpt $fbk
 		set found 1
 		DEBUG {puts "only found backward from $first at $fbk"}
-	} elseif {$fbk==""} {
+	} elseif {[string equal $fbk ""]} {
 		set fpt $ffw
 		set found 1
 		DEBUG {puts "only found foward from $first at $ffw"}
 	} else {
 		# matches forward and backward.  pick closer one
 		scan $first "%d.%d" line char
-		scan $ffw "%d.%d" fline fchar; set difffw [expr $fline-$line]; set dcfw [expr abs($fchar-$char)]
-		scan $fbk "%d.%d" bline bchar; set diffbk [expr $line-$bline]; set dcbk [expr abs($char-$bchar)]
-		if {$diffbk<$difffw} {set fpt $fbk} elseif {$difffw<$diffbk} {set fpt $ffw} {
+		scan $ffw "%d.%d" fline fchar; set difffw [expr {$fline-$line}]; set dcfw [expr {abs($fchar-$char)}]
+		scan $fbk "%d.%d" bline bchar; set diffbk [expr {$line-$bline}]; set dcbk [expr {abs($char-$bchar)}]
+		if {$diffbk<$difffw} {set fpt $fbk} elseif {$difffw<$diffbk} {set fpt $ffw} else {
 			# tie, go to characters
 			if {$dcbk<$dcfw} {set fpt $fbk} else {set fpt $ffw}
 		}
@@ -470,12 +431,12 @@ proc manHighlightAttach {t first firsttxt predelta fhooklen  ldelta lasttxt post
 			set fpt [$t index "$fpt+${delta}c"]
 
 			set txt [$t get $fpt "$fpt+1000c"]
-			if ![regexp -indices -- [manHighRegexp $fextxt] $txt all] { set found 0 }
+			if {![regexp -indices -- [manHighRegexp $fextxt] $txt all]} { set found 0 }
 
 		} elseif {$flen>=20} {
 			# searching by long excerpt
 			# if match far away, axe it, in favor of possible closer if shorter match
-			if {[expr abs($line-$fline)>200]} { set found 0 }
+			if {[expr {abs($line-$fline)>200}]} { set found 0 }
 		}
 	}
 
@@ -487,7 +448,7 @@ proc manHighlightAttach {t first firsttxt predelta fhooklen  ldelta lasttxt post
 
 		# if searching by long excerpt text, chop it and try again
 		} elseif {$flen>10} {
-			set chop [max 9 [expr int($flen/2)]]
+			set chop [max 9 [expr {int($flen/2)}]]
 			return [manHighlightAttach $t $first [string range $fhooktxt 0 $chop] 0 0  $ldelta $lasttxt $postdelta $lhooklen "DICEY"]
 		} else {
 			return "LOSE"
@@ -506,13 +467,13 @@ proc manHighlightAttach {t first firsttxt predelta fhooklen  ldelta lasttxt post
 #puts "searching backward for $lregexp"
 	set lfw [$t search -forwards -regexp -count lfwcnt $viz $lregexp $last end]
 	set lbk [$t search -backwards -regexp -count lbkcnt $viz $lregexp $last $fpt]
-	if {$lfw=="" && $lbk==""} {
-	} elseif {$lfw==""} {
+	if {[string equal $lfw ""] && [string equal $lbk ""]} {
+	} elseif {[string equal $lfw ""]} {
 		set lpt $lbk
 		set llen $lbkcnt
 		set found 1
 		DEBUG {puts "end only found backward from $fpt at $lbk"}
-	} elseif {$lbk==""} {
+	} elseif {[string equal $lbk ""]} {
 		set lpt $lfw
 		set llen $lfwcnt
 		set found 1
@@ -520,9 +481,9 @@ proc manHighlightAttach {t first firsttxt predelta fhooklen  ldelta lasttxt post
 	} else {
 		# match forward and backward.  pick closer one -- need to adjust for length of match
 		scan $fpt "%d.%d" line char
-		scan $lfw "%d.%d" fline fchar; set difffw [expr $fline-$line]; set dcfw [expr abs($fchar-$char)]
-		scan $lbk "%d.%d" bline bchar; set diffbk [expr $line-$bline]; set dcbk [expr abs($char-$bchar)]
-		if {$diffbk<$difffw} {set lpt $lbk; set llen $lbkcnt} elseif {$difffw<$diffbk} {set lpt $lfw; set llen $lfwcnt} {
+		scan $lfw "%d.%d" fline fchar; set difffw [expr {$fline-$line}]; set dcfw [expr {abs($fchar-$char)}]
+		scan $lbk "%d.%d" bline bchar; set diffbk [expr {$line-$bline}]; set dcbk [expr {abs($char-$bchar)}]
+		if {$diffbk<$difffw} {set lpt $lbk; set llen $lbkcnt} elseif {$difffw<$diffbk} {set lpt $lfw; set llen $lfwcnt} else {
 			# tie, go to characters
 			if {$dcbk<$dcfw} {set lpt $lbk; set llen $lbkcnt} else {set lpt $lfw; set llen $lfwcnt}
 		}
@@ -535,20 +496,20 @@ proc manHighlightAttach {t first firsttxt predelta fhooklen  ldelta lasttxt post
 		if {$lhooklen} {
 			# should make this check when do $t search ...
 			# match only as far as excerpt (not hook) -- chop off trailing context
-			set e [manHighRegexp $lhookextxt]
+			set rx [manHighRegexp $lhookextxt]
 			# this had better match!
-			set posti [$t search -count llen -regexp $viz $e $lpt end]
-			DEBUG {puts "$t search -count llen -regexp $viz $e $lpt end"}
+			set posti [$t search -count llen -regexp $viz $rx $lpt end]
+			DEBUG {puts "$t search -count llen -regexp $viz $rx $lpt end"}
 			# off by one error in searching backwards
 #			DEBUG {puts "backward must = $must, delta=$delta, llen=$llen"}
 #			set llen [string length [$t get $fpt "$lpt+${len}c"]]
 #			incr llen -$delta
 
 
-			set e [manHighRegexp $lextxt]; append e "\$"
+			set rx [manHighRegexp $lextxt]; append rx "\$"
 			set txt [$t get "$lpt-1000c" "$lpt+${llen}c"]
-#puts "backward regexp [regexp $e $txt]: find |$lextxt| in |[string range $txt [expr [string length $txt]-100] end]|"
-			if ![regexp -indices -- $e $txt all] { set found 0 }
+#puts "backward regexp [regexp $rx $txt]: find |$lextxt| in |[string range $txt [expr [string length $txt]-100] end]|"
+			if {![regexp -indices -- $rx $txt all]} {set found 0}
 #puts "*** no match to excerpt"; #
 		}
 
@@ -557,7 +518,7 @@ proc manHighlightAttach {t first firsttxt predelta fhooklen  ldelta lasttxt post
 		if {$llen>=20} {
 			# if new end too far down, assume it was searching for common text 
 			# and latched onto an unsuspecting host
-			if {$nldelta>[expr 10*$ldelta]} { set found 0 }
+			if {$nldelta>[expr {10*$ldelta}]} {set found 0}
 		}
 	}
 
@@ -566,9 +527,9 @@ proc manHighlightAttach {t first firsttxt predelta fhooklen  ldelta lasttxt post
 			return [manHighlightAttach $t $fpt $firsttxt $predelta $fhooklen   $ldelta $lextxt 0 0  $status]
 
 		} elseif {$llen>10} {
-			set chop [max 9 [expr int($llen/2)]]
+			set chop [max 9 [expr {int($llen/2)}]]
 			# keep end $chop characters
-			set d [expr $llen-$chop]; set lhooktxt [string range $lhooktxt $d end]
+			set d [expr {$llen-$chop}]; set lhooktxt [string range $lhooktxt $d end]
 			return [manHighlightAttach $t $fpt $firsttxt $predelta $fhooklen  $ldelta $lhooktxt 0 0  "DICEY"]
 
 		} else {
