@@ -10,7 +10,7 @@ proc manPreferencesMake {{w0 ""}} {
 # don't do global man here
 
 	set w .prefs
-	if {[winfo exists $w]||$w0==""} {return $w}
+	if {[winfo exists $w]||[string equal $w0 ""]} {return $w}
 
 	toplevel $w; wm resizable $w 0 0
 	wm geometry $w $prefedit(geom-prefs)
@@ -18,7 +18,7 @@ proc manPreferencesMake {{w0 ""}} {
 	wm withdraw $w
 
 	set f [frame $w.pages]
-	foreach i {"Fonts" "Colors" "See" "Outline" "Database" "Icon" "Misc"} {
+	foreach i {"Fonts" "Colors" "See" "Outline" "Database" "Window" "Misc"} {
 		set il [string tolower $i]
 		radiobutton $f.$il -text $i -command manPreferences -variable manx(prefscreen) -value $il
 		pack $f.$il -side left -fill x -padx 4
@@ -35,10 +35,10 @@ proc manPreferencesMake {{w0 ""}} {
 			diffd "Text deleted from last version"  diffc "Text changed from last version"  diffa "Text added since last version"} {
 		lappend manx(vars-$group) $var-style
 
-		if [info exists $var-family] {lappend manx(vars-$group) $var-family}
+		if {[info exists $var-family]} {lappend manx(vars-$group) $var-family}
 		lappend manx(vars-$group) $var-style
 		# $var-points -- diff[dca] don't have points
-		if [info exists $var-points] {lappend manx(vars-$group) $var-points}
+		if {[info exists $var-points]} {lappend manx(vars-$group) $var-points}
 		set f [frame $g.font$var]
 		label $f.l -text $txt
 		[eval tk_optionMenu $f.style prefedit($var-style) $manx(styles)] configure -tearoff no
@@ -62,7 +62,6 @@ proc manPreferencesMake {{w0 ""}} {
 #	pack $f.choice -side right -padx 2
 
 	pack $g.fontgui $g.fonttext $g.fontvol $g.fontdiffa $g.fontdiffc $g.fontdiffd -fill x -pady 3 -padx 4
-	if $manx(iswdiff) {pack forget $g.fontdiffc}
 
 
 
@@ -76,13 +75,13 @@ proc manPreferencesMake {{w0 ""}} {
 		label $f.l -text $txt
 		foreach j {{fg "foreground"} {bg "background"}} {
 			foreach {jvar jtxt} $j break
-			if {$jvar=="fg"} {set jopp "bg"} {set jopp "fg"}
+			if {[string equal $jvar "fg"]} {set jopp "bg"} else {set jopp "fg"}
 			set mb $f.$var$jvar
 			[set m [eval tk_optionMenu $mb prefedit($var$jvar) $man(colors)]] configure -tearoff no
 			# when monochrome, keep foreground and background colors opposites!
 			if {$manx(mono)} {
 				foreach k $man(colors) {
-					set copp [lindex $prefedit(colors) [expr 1-[lsearch $prefedit(colors) $k]]]
+					set copp [lindex $prefedit(colors) [expr {1-[lsearch $prefedit(colors) $k]}]]
 					$m entryconfigure $k -command "set prefedit($var$jopp) $copp; set prefedit($var$jvar) $k"
 				}
 			}
@@ -91,8 +90,12 @@ proc manPreferencesMake {{w0 ""}} {
 		pack $f.${var}bg [label $f.${var}on -text "on"] $f.${var}fg -side right -padx 4
 	}
 
-	foreach {var fb txt} {manref f "Man page references"   isearch b "Incremental search hits"
-			search b "Regexp search hits"   highlight b "Highlights"} {
+	foreach {var fb txt} {
+			synopsisargs b "Name and Synopsis arguments"
+			manref f "Man page references"   isearch b "Incremental search hits"
+			search b "Regexp search hits"   highlight b "Highlights"
+			autokey f "Keywords"
+		} {
 		lappend manx(vars-$group) $var
 		set f [frame $g.$var]
 		label $f.l -text $txt
@@ -100,14 +103,14 @@ proc manPreferencesMake {{w0 ""}} {
 		[set m [eval tk_optionMenu [set mb $f.$var] prefedit($var) $manx(highs)]] configure -tearoff no
 			foreach k $manx(highs) {
 				if {[lsearch $man(colors) $k]==-1} {set val $k} \
-				else {if {$fb=="f"} { set val "-foreground [list $k]"} { set val "-background [list $k]" } }
+				else {if {[string equal $fb "f"]} { set val "-foreground [list $k]"} else { set val "-background [list $k]" } }
 				$m entryconfigure $k -command "set prefedit($var) [list $val]"
 			}
 		pack $f.l -side left -fill x
 		pack $mb -side right -padx 4
 	}
 
-	pack $g.text $g.gui $g.butt $g.active $g.selection $g.manref $g.isearch $g.search $g.highlight \
+	pack $g.text $g.highlight $g.gui $g.butt $g.active $g.selection $g.synopsisargs $g.manref $g.isearch $g.search $g.autokey \
 		-fill x -expand yes -pady 3 -padx 4
 
 
@@ -116,17 +119,19 @@ proc manPreferencesMake {{w0 ""}} {
 	set g [frame $w.[set group "see"]]
 
 	foreach {var txt} {
+			wordfreq "Page summary as word freqency counts"
 			headfoot "Header, footer, date at bottom"
 			maxpage "Page content only, except when menus active by Tab or mouse into region"
 			documentmap "Document map (adjacent to scrollbar)"
 			scrollbarside "Scrollbar side"
 			textboxmargin "Text box internal margin (in pixels)"
 			volcol "Width of columns in Volumes list"
-			high,vcontext "Back context for Highlights jump"
+			high,vcontext "Back context for Highlights jump (lines)"
 			error-effect "Status line error/warning effect"
 			subvols "Subvolumes as submenus in Volumes"
 			apropostab "Tab stop in apropos list"
-			rebus "Rebus (Icons instead of words) for: file, TeX, ..."
+			rebus "Rebus (icons instead of words) for: file, TeX, ..."
+			lengthchunk "Page length reported in (estimated)"
 #			diffbar "Generate change bars"
 		} {
 		lappend manx(vars-$group) $var
@@ -144,7 +149,7 @@ proc manPreferencesMake {{w0 ""}} {
 	}
 
 # $g.diffbar
-	pack $g.headfoot $g.maxpage $g.subvols $g.documentmap $g.high,vcontext $g.volcol $g.apropostab $g.rebus $g.scrollbarside $g.textboxmargin $g.error-effect \
+	pack $g.wordfreq $g.headfoot $g.lengthchunk $g.maxpage $g.subvols $g.documentmap $g.high,vcontext $g.volcol $g.apropostab $g.rebus $g.scrollbarside $g.textboxmargin $g.error-effect \
 		-fill x -pady 3 -padx 4
 
 
@@ -154,6 +159,7 @@ proc manPreferencesMake {{w0 ""}} {
 
 	foreach {var txt} {
 			outline "Outlining state at page load"
+			tidyout "With outline \"smart scroll down\", collapse previous section"
 			manfill "Excerpt "
 			manfill-show ""
 			highlight-show "Highlights in collapsed outline visible"
@@ -183,7 +189,10 @@ proc manPreferencesMake {{w0 ""}} {
 	entry $g.manfill.e -width 40 -textvariable prefedit(manfill-sects) -relief sunken
 	pack $g.manfill.e -after $g.manfill.l -side left
 
-	foreach {var txt} {outlinebut "In outline \"all but\", show"   autosearch "Automatically search for regexp"} {
+	foreach {var txt} {
+		outlinebut "In outline \"all but collapsed\", show"   autokeywords "Keywords"
+		autosearchnb "Auto search regexp as Notemarks"   autosearch "Auto search regexp NOT as Notemarks"
+	} {
 		lappend manx(vars-$group) $var
 		set f [frame $g.$var]
 		label $f.l -text $txt
@@ -201,16 +210,16 @@ proc manPreferencesMake {{w0 ""}} {
 		pack $g.$var -side right -fill none -in $f
 	}
 
-	pack $g.outline $g.outlinebut $g.manfill $g.highlight-show $g.options-show $g.manref-show $g.search-show $g.searchcontext $g.autosearch $g.showsectmenu \
+	pack $g.outline $g.outlinebut $g.tidyout $g.manfill $g.highlight-show $g.options-show $g.manref-show $g.search-show $g.searchcontext $g.autosearchnb $g.autosearch $g.autokeywords $g.showsectmenu \
 # $g.outline-show
 		-fill x -pady 3 -padx 4
 
 
 
-	### icon-related
-	set g [frame $w.[set group "icon"]]
+	### window-related
+	set g [frame $w.[set group "window"]]
 
-	foreach {var txt} {iconify "Iconify on startup" } {
+	foreach {var txt} {autoraise "Auto raise window when mouse enters"  autolower "Auto lower window when mouse leaves"  iconify "Iconify on startup"  focus "Text entry focus set by"} {
 		lappend manx(vars-$group) $var
 		set f [frame $g.$var]
 		label $f.l -text $txt
@@ -239,8 +248,8 @@ proc manPreferencesMake {{w0 ""}} {
 	set ring {iconname iconbitmap iconmask iconposition}; set ringl [llength $ring]
 	for {set i 0} {$i<$ringl} {incr i} {
 		set wig $g.[lindex $ring $i].e
-		foreach k {Tab Return} { bind $wig <KeyPress-$k> "focus $g.[lindex $ring [expr ($i+1)%$ringl]].e"; break }
-		bind $wig <Shift-KeyPress-Tab> "focus $g.[lindex $ring [expr ($i-1)%$ringl]].e; break"
+		foreach k {Tab Return} { bind $wig <KeyPress-$k> "focus $g.[lindex $ring [expr {($i+1)%$ringl}]].e"; break }
+		bind $wig <Shift-KeyPress-Tab> "focus $g.[lindex $ring [expr {($i-1)%$ringl}]].e; break"
 	}
 
 	# file completion for bitmap names
@@ -249,7 +258,7 @@ proc manPreferencesMake {{w0 ""}} {
 		bind $e <KeyPress-Escape> "manFilecompleteLocal $e"
 	}
 
-	pack $g.iconify $g.iconname $g.iconbitmap $g.iconmask $g.iconposition \
+	pack $g.autoraise $g.autolower $g.iconify $g.iconname $g.iconbitmap $g.iconmask $g.iconposition $g.focus \
 		-fill x -pady 3 -padx 4
 
 
@@ -284,18 +293,21 @@ proc manPreferencesMake {{w0 ""}} {
 	}
 
 
-	foreach {var txt} {printers "Printer list (space separated)"} {
-		lappend manx(vars-$group) $var
+	if {![string equal $man(print) ""]} {
+		foreach {var txt} {printers "Printer list (space separated)"} {
+			lappend manx(vars-$group) $var
 
-		set f [frame $g.$var]
-		label $f.l -text $txt
-		entry $f.e -width 40 -textvariable prefedit($var) -relief sunken
+			set f [frame $g.$var]
+			label $f.l -text $txt
+			entry $f.e -width 40 -textvariable prefedit($var) -relief sunken
 
-		pack $f.l -side left -fill x
-		pack $f.e -side right
+			pack $f.l -side left -fill x
+			pack $f.e -side right
+		}
+		pack $g.printers -fill x -pady 3 -padx 4
 	}
 
-	pack $g.printers $g.hyperclick $g.incr,case $g.regexp,case $g.subsect $g.maxhistory $g.shortcuts-sort $g.showrandom $g.strictmotif \
+	pack $g.hyperclick $g.incr,case $g.regexp,case $g.subsect $g.maxhistory $g.shortcuts-sort $g.showrandom $g.strictmotif \
 # $g.zaphy
 		-fill x -pady 3 -padx 4
 
@@ -305,9 +317,14 @@ proc manPreferencesMake {{w0 ""}} {
 
 	foreach {var txt} {
 			nroffsave "Cache formatted (nroff'ed) pages"
+#			fastman "Don't cache man if formatting takes less than (sec)"
+#			fasttex "Don't cache Texinfo if formatting takes less than (sec)"
+			fsstnd-always "Cache directory"
 			columns "Width of man pages, in columns"
 			recentdays {"Recent" volume age, in days}
 			preferGNU "Prefer GNU versions of pages (e.g., od => god)"
+			preferTexinfo "Prefer Texinfo to man"
+			tryfuzzy "Try fuzzy match if exact fails"
 			indexglimpse "Glimpse indexing"
 			maxglimpse "Maximum Glimpse hits (per man hierarchy)"
 			maxglimpseexcerpt "Excerpt Glimpse hits if number of pages with hits less than"} {
@@ -324,12 +341,16 @@ proc manPreferencesMake {{w0 ""}} {
 		pack $f.l -side left -fill x
 		pack $f.high -side right
 	}
+	entry $g.fsstnd-always.e -width 30 -textvariable prefedit(fsstnddir) -relief sunken
+	pack $g.fsstnd-always.e -side right
+	lappend manx(vars-$group) fsstnddir
 
 
 	foreach {var txt} {glimpsestrays "Distributed stray cats / unified index"
-			fsstnddir "Cache directory if .../catN unwritable"
+			indexalso "Additional directories for full text"
+#			fsstnddir "Cache directory if .../catN unwritable"
 # (useful if long lines)
-			texinfodir "Texinfo index directory"
+			texinfodir "Texinfo dir/cache directory"
 #			rfcdir "rfc-index.txt index directory"
 		} {
 		lappend manx(vars-$group) $var
@@ -342,10 +363,10 @@ proc manPreferencesMake {{w0 ""}} {
 		pack $f.e -side right
 	}
 
-	pack $g.nroffsave $g.columns $g.fsstnddir $g.recentdays $g.preferGNU \
-		$g.maxglimpse $g.maxglimpseexcerpt $g.indexglimpse $g.glimpsestrays $g.texinfodir \
+	pack $g.nroffsave $g.columns $g.fsstnd-always $g.texinfodir $g.recentdays $g.preferTexinfo $g.tryfuzzy $g.preferGNU \
+		$g.maxglimpse $g.maxglimpseexcerpt $g.indexglimpse $g.glimpsestrays $g.indexalso \
 		-fill x -pady 3 -padx 4
-	if ![string match "*groff*/tmp/ll -*" $man(format)] {pack forget $g.columns}
+	if {![string match "*groff*/tmp/ll -*" $man(format)]} {pack forget $g.columns}
 
 
 
@@ -396,17 +417,15 @@ proc manFilecompleteLocal {t} {
 proc manPreferencesGet {{cmd "fill"}} {
 	global man manx default prefedit cancel curedit
 
-	# could use switch, except for command named default
-	if {$cmd=="fill"} {
-		foreach i [array names default] {set prefedit($i) [set curedit($i) [set cancel($i) $man($i)]]}
-	} elseif {$cmd=="default"} {
-		foreach i $manx(vars-$manx(prefscreen)) {set prefedit($i) $default($i)}
-	} elseif {$cmd=="cancel"} {
-		foreach i [array names default] {set prefedit($i) $cancel($i)}
-	} elseif {$cmd=="man"} {
-		foreach i [array names default] {set man($i) $prefedit($i)}
-	} elseif {$cmd=="curedit"} {
-		foreach i [array names default] {set curedit($i) $prefedit($i)}
+	# conflict of command name and special case of switch command
+	if {$cmd=="default"} {set cmd "prefdefault"}
+
+	switch -exact $cmd {
+	fill {foreach i [array names default] {set prefedit($i) [set curedit($i) [set cancel($i) $man($i)]]}}
+	prefdefault {foreach i $manx(vars-$manx(prefscreen)) {set prefedit($i) $default($i)}}
+	cancel {foreach i [array names default] {set prefedit($i) $cancel($i)}}
+	man {foreach i [array names default] {set man($i) $prefedit($i)}}
+	curedit {foreach i [array names default] {set curedit($i) $prefedit($i)}}
 	}
 }
 
@@ -418,11 +437,11 @@ proc manPreferences {{screen ""}} {
 	# show right grouping
 	set w [manPreferencesMake bozo]
 	raise $w
-	if {$screen==""} {set screen $manx(prefscreen)} {set manx(prefscreen) $screen}
+	if {[string equal $screen ""]} {set screen $manx(prefscreen)} else {set manx(prefscreen) $screen}
 	set prev $manx(oldprefscreen)
 
-	if {$screen!=$prev} {
-		if {$prev!=""} {
+	if {![string equal $screen $prev]} {
+		if {![string equal $prev ""]} {
 			pack forget $w.$prev
 #			$w.pages.$prev configure -relief raised
 		}
@@ -433,17 +452,17 @@ proc manPreferences {{screen ""}} {
 		set manx(oldprefscreen) $screen
 	}
 
-	if ![winfo ismapped $w] {
+	if {![winfo ismapped $w]} {
 		manPreferencesGet fill
 		wm deiconify $w; grab set $w
 	}
 }
 
-proc manPresDefaultsSet {} {
+proc manPrefDefaultsSet {} {
 	global man
 
 	# fonts & colors
-	foreach {var txt} {gui ""   butt "Button."   butt "Menubutton."   butt "Radiobutton." \
+	foreach {var txt} {gui ""   butt "Button."   butt "Menubutton."   butt "Radiobutton." 
 			butt "Checkbutton."   text "Text."} {
 # {gui "Scrollbar."}} {
 		option add Tkman*${txt}Foreground $man(${var}fg) 61
@@ -456,6 +475,31 @@ proc manPresDefaultsSet {} {
 	option add Tkman*highlightBackground $man(activebg) 61
 
 	option add Tkman*selectColor $man(buttfg) 61
+	option add Tkman*font gui 61
+
+
+	eval font configure textpro [spec2font $man(text-family) $man(text-style) $man(text-points)]
+#puts "set textpro to [font actual textpro]"
+	eval font configure gui [spec2font $man(gui-family) $man(gui-style) $man(gui-points)]
+#puts "set gui to [font actual gui]"
+	eval font configure guisymbol [spec2font "symbol" $man(gui-style) $man(gui-points)]
+	eval font configure guimono [spec2font "courier" $man(gui-style) $man(gui-points)]
+	eval font configure textmono [spec2font "Courier" $man(text-style) $man(text-points)]
+	eval font configure peek [spec2font $man(text-family) "italics" $man(text-points) "s"]
+#	foreach f {diffa diffc diffd} {
+#		eval font configure $f [spec2font $man($f-family) $man($f-style) $man(text-points)]
+#	}
+
+	# bitmaps
+	foreach bitmap [image names] {
+		if {[regexp "face|icon" $bitmap]} {
+			# face and icon always black on white
+		} elseif {[regexp "sections|history|random" $bitmap]} {
+			$bitmap configure -foreground $man(buttfg) -background $man(buttbg)			
+		} else {
+			$bitmap configure -foreground $man(textfg) -background {}
+		}
+	}
 }
 
 
@@ -465,13 +509,13 @@ proc manPreferencesSet {} {
 
 	set change 0
 	foreach i [array names default] {
-		if {$curedit($i)!=$prefedit($i)} {
+		if {![string equal $curedit($i) $prefedit($i)]} {
 			set change 1
 			break
 		}
 	}
 #puts "* manPreferencesSet, change=$change"
-	if !$change return
+	if {!$change} return
 
 	# random updates
 	set mani($prefedit(glimpsestrays),dirs) $mani($man(glimpsestrays),dirs)
@@ -483,27 +527,9 @@ proc manPreferencesSet {} {
 	# # # set keybindings--later
 
 	# fonts -- text, gui (main and preferences windows)
-	manPresDefaultsSet
-	eval font configure textpro [spec2font $man(text-family) $man(text-style) $man(text-points)]
-#puts "set textpro to [font actual textpro]"
-	eval font configure gui [spec2font $man(gui-family) $man(gui-style) $man(gui-points)]
-#puts "set gui to [font actual gui]"
-	eval font configure guisymbol [spec2font "symbol" $man(gui-style) $man(gui-points)]
-	eval font configure guimono [spec2font "courier" $man(gui-style) $man(gui-points)]
-	eval font configure textmono [spec2font "Courier" $man(text-style) $man(text-points)]
-	eval font configure peek [spec2font $man(text-family) italics $man(text-points) "s"]
-#	foreach f {diffa diffc diffd} {
-#		eval font configure $f [spec2font $man($f-family) $man($f-style) $man(text-points)]
-#	}
+	manPrefDefaultsSet
 
 	resetcolors
-	# bitmaps
-	foreach bitmap [image names] {
-		if {[string match "*Rebus" $bitmap] || $bitmap=="opened" || $bitmap=="closed"} { # face and icon always black on white
-			$bitmap configure -foreground $man(textfg) -background $man(textbg)
-		}
-	}
-
 
 	foreach i [list .occ .paths] {$i configure -selectcolor $man(guifg)}
 
@@ -521,7 +547,7 @@ proc manPreferencesSetGlobal {} {
 	# icon-related
 	# ... need to reference man() to get new values, but manx() has command line options
 	foreach i {iconname iconposition iconbitmap iconmask} {
-		if {$man($i)!=$curedit($i)} {set manx($i) $man($i)}
+		if {![string equal $man($i) $curedit($i)]} {set manx($i) $man($i)}
 	}
 
 	manShortcuts .man init
@@ -529,36 +555,58 @@ proc manPreferencesSetGlobal {} {
 	set manx(effcols) ""
 	if {[string match "*groff*$manx(longtmp) -*" $man(format)] && $man(columns)!=65} {set manx(effcols) "@$man(columns)"}
 
-	if {[[set m2 .occ.kill] index end]=="none" || $curedit(printers)!=$man(printers) } {
+	if {![string equal $man(print) ""] && ([string equal [[set m2 .occ.kill] index end] "none"] || ![string equal $curedit(printers) $man(printers)]) } {
 		set plist [string trim $man(printers)]
 		# always put default printer in list
-		if [lsearch $plist $manx(printer)]==-1 { set plist [concat $manx(printer) $plist] }
+		if {[lsearch $plist $manx(printer)]==-1} {set plist [concat $manx(printer) $plist]}
 
 		#if {[llength $plist]==1} => always want level of indirection for printing
 		$m2 delete 0 end
 		foreach p $plist { $m2 add command -label $p -command "manPrint \$curwin $p" }
-		if ![llength $plist] { $m2 add command -label "(default)" -command "manPrint \$curwin" }
+		if {![llength $plist]} {$m2 add command -label "(default)" -command "manPrint \$curwin"}
 	}
 
-	if {$curedit(subvols)!=$man(subvols)} {manMakeVolList 1}
+	if {![string equal $curedit(subvols) $man(subvols)]} {manMakeVolList 1}
 
 	# update text tags and other .man* bits
 	foreach w [lmatches ".man*" [winfo children .]] {manPreferencesSetMain $w}
+
+	foreach w [lmatches ".man*" [winfo children .]] {
+		foreach i {info kind mantypein} {bind $w.$i <Enter> [expr $man(focus)?"focus $w.mantypein":""]}
+		foreach i {vf show v} {bind $w.$i <Enter> [expr $man(focus)?"focus $w.show":""]}
+		bind $w.search <Enter> [expr $man(focus)?"focus $w.search.t":""]
+	}
+
+
+	# compute scaling factors
+	set cols $man(columns)
+	# screens based on font, window size, line length
+	set t .man.show
+	set fh [font metrics [$t cget -font] -linespace]
+	if {$cols>=200} {set fh [expr {$fh*2.2}]}; # say 6 lines per paragraph, but lotsa blank lines, lotsa single lines
+	set wh [winfo height $t]
+	set manx(screen-scale) [expr {$wh/$fh}]
+	# pages based on line length
+	set lpp 60; set scale $lpp
+	if {$cols<80} {set scale [expr {$scale*1.5}]} elseif {$cols>=200} {set scale [expr {$scale/2.2}]}
+	set manx(page-scale) $scale
+	set manx(page-fhscale) $fh
 }
 
+
 proc manPreferencesSetMain {w} {
 	global man manx curedit
 
-	if ![string match ".man*" $w] return
+	if {![string match ".man*" $w]} return
 
 	if {[regexp $manx(posnregexp) $manx(iconposition) all x y]} {
 		wm iconposition $w $x $y
 	}
 	foreach i {iconbitmap iconmask iconwindow} {wm $i $w ""}
 
-	if {$manx(iconbitmap)=="(default)" || $manx(iconbitmap)=="default"} {
+	if {[regexp {\)?default\)?} $manx(iconbitmap)]} {
 		set iw ".iconwindow[string range $w 4 end]"
-		if ![winfo exists $iw] {
+		if {![winfo exists $iw]} {
 			toplevel $iw; label $iw.l -image icon; pack $iw.l
 			# bug in ctwm doesn't deiconify if using icon window
 			# (default deiconify Button-1 in ctwm?)
@@ -570,8 +618,8 @@ proc manPreferencesSetMain {w} {
 		# everybody shares same icons
 		# (null string for name means no icon)
 		foreach i {iconbitmap iconmask} {
-			if {$manx($i)!=""} {
-				if [catch {wm $i $w @$manx($i)} info] {
+			if {![string equal $manx($i) ""]} {
+				if {[catch {wm $i $w @$manx($i)} info]} {
 					puts stderr "Bad $i: $manx($i).  Fix in Preferences/Icon."
 #					tk_dialog .dialog "BAD [string toupper $i]" "Bad $i: $manx($i).  Fix in Preferences/Icon." "" 0 " OK "
 				}
@@ -584,7 +632,7 @@ proc manPreferencesSetMain {w} {
 	set t $w.show
 
 	pack $w.v -side $man(scrollbarside)
-	if $man(documentmap) { pack $w.cf -after $w.v -side $man(scrollbarside) -fill y } else { pack forget $w.cf }
+	if {$man(documentmap)} { pack $w.cf -after $w.v -side $man(scrollbarside) -fill y } else { pack forget $w.cf }
 
 	if {$man(maxpage)} {
 		pack forget $w.info; pack forget $w.kind; pack forget $w.search
@@ -615,7 +663,7 @@ proc manPreferencesSetMain {w} {
 
 	# the scrollbar is an oddball
 	$w.v configure -troughcolor $man(guibg)
-	$w.v configure -background [expr {$man(buttbg)!=$man(guibg)?$man(buttbg):$man(guibg)}]
+	$w.v configure -background [expr {![string equal $man(buttbg) $man(guibg)]?$man(buttbg):$man(guibg)}]
 
 	# text widget fonts and tags
 	$t configure -padx $man(textboxmargin) -pady $man(textboxmargin)
@@ -623,18 +671,22 @@ proc manPreferencesSetMain {w} {
 # -tabs 0.2i -- tabs set to 5 spaces in current font
 
 	$t tag configure volume -font [spec2font $man(vol-family) $man(vol-style) $man(vol-points)] -tabs $man(volcol)
+# -lmargin2 $man(volcol)
 	$t tag configure apropos -font [spec2font $man(vol-family) $man(vol-style) $man(vol-points)] -tabs $man(apropostab) -lmargin2 $man(apropostab)
 
 	$t tag configure sel -foreground $man(selectionfg) -background $man(selectionbg)
 
 	set man(highlight-meta) $man(highlight)
+	set man(autosearchtag) $man(search)
 	foreach v $manx(tags) {
 #puts "$t => [winfo class $t]"
 		$t tag configure $v -font "" -foreground "" -background "" -underline no
-		set change ""; set newfont 0
+		set change ""; set newfont 0; set pending 0
 		set fam $man(text-family); set sty $man(text-style); set poi $man(text-points); set poi2 "m"
 		foreach g [subst $man($v)] {
-			switch -exact -- $g {
+#DEBUG {puts $g}
+			if {$pending} {append change " " [list $g]; set pending 0; continue}
+			switch -glob -- $g {
 				# normal should be plain
 				normal {}
 				underline {append change " -underline yes"}
@@ -664,6 +716,7 @@ proc manPreferencesSetMain {w} {
 				center {
 					append change " -justify $g"
 				}
+				-* {append change " " [list $g]; set pending 1}
 				default {
 #puts "lsearch $g => [lsearch $manx(fontfamilies) [string tolower $g]]"
 					if {[lsearch $manx(fontfamilies) [string tolower $g]]!=-1} {set fam $g; set newfont 1
@@ -673,26 +726,26 @@ proc manPreferencesSetMain {w} {
 		}
 		if {$newfont} {append change " -font \"[spec2font $fam $sty $poi $poi2]\""}
 #puts "change $v = $change"
-		if {$change!=""} {
+		if {![string equal $change ""]} {
 			eval $t tag configure $v $change
-			if {$v=="highlight"} {catch {eval $w.high configure $change}}
-#			if {$v=="search"} {catch {eval $w.search.s configure $change}}
+			if {[string equal $v "highlight"]} {catch {eval $w.high configure $change}}
+#			if {[string equal $v "search"]} {catch {eval $w.search.s configure $change}}
 		}
 	}
 	$t tag raise sel
 	$t tag configure sfirstvis -relief [expr {$man(search,bcontext)+$man(search,bcontext)>1?"raised":"flat"}]
 
-	if $man(showsectmenu) {pack $w.sections -before $w.high -side left -padx 4} else {pack forget $w.sections}
+	if {$man(showsectmenu)} {pack $w.sections -before $w.high -side left -padx 4} else {pack forget $w.sections}
 
 #	set inx [lsearch $manx(outline-show-v) $man(outline-show)]
 #	foreach tag [lrange $manx(outline-show-v) 1 $inx] {$t tag configure $tag -elide 0}
 #	foreach tag [lrange $manx(outline-show-v) [expr $inx+1] end] {$t tag configure $tag -elide ""}
 
 
-	if $man(showrandom) {pack $w.random -before $w.vols -side left -padx 10} else {pack forget $w.random}
+	if {$man(showrandom)} {pack $w.random -before $w.vols -side left -padx 10} else {pack forget $w.random}
 
 
-	if {$curedit(hyperclick)!=$man(hyperclick)} {manHyper $w ""}
+	if {![string equal $curedit(hyperclick) $man(hyperclick)]} {manHyper $w ""}
 }
 
 
@@ -700,8 +753,8 @@ proc resetcolors {{w .}} {
 	global man curedit
 
 	set c [winfo class $w]
-	set g "gui"; if {$c=="Text"} {set g "text"} elseif {[string match "*utton" $c]} {set g "butt"}
-#||$c=="Entry"
+	set g "gui"; if {[string equal $c "Text"]} {set g "text"} elseif {[string match "*utton" $c]} {set g "butt"}
+#||[string equal $c "Entry"]
 	set foreground [set selector [set insertbackground $man(${g}fg)]]
 	set background $man(${g}bg)
 	set ofg $curedit(${g}fg)
@@ -709,9 +762,9 @@ proc resetcolors {{w .}} {
 
 #puts "checking $w, class $c"
 	foreach i {foreground background insertbackground selectcolor} {
-		if ![catch {set color [$w cget -$i]}] {
-			 if {$color==$ofg} {$w configure -$i $foreground} \
-			 elseif {$color==$obg} {$w configure -$i $background}
+		if {![catch {set color [$w cget -$i]}]} {
+			 if {[string equal $color $ofg]} {$w configure -$i $foreground} \
+			 elseif {[string equal $color $obg]} {$w configure -$i $background}
 		}
 	}
 
