@@ -5,7 +5,7 @@
 
 # kill old TkMen
 set tkmen {}
-foreach interp [winfo interps] {if [string match "tkman*" $interp] {lappend tkmen $interp}}
+foreach interp [winfo interps] {if {[string match "tkman*" $interp]} {lappend tkmen $interp}}
 
 set cnt [llength $tkmen]
 if {$cnt==1} {
@@ -14,7 +14,7 @@ if {$cnt==1} {
 	# if multiple instantiations, find one on same machine
 	set hostname [info hostname]
 	foreach man $tkmen {
-		if {[send $man info hostname]==$hostname} {
+		if {[string equal [send $man info hostname] $hostname]} {
 			catch {send $man "manSave; exit 0"}
 			break
 		}
