@@ -3,6 +3,7 @@
 #
 # Tom Phelps (phelps@ACM.org)
 #
+# possible additions:
 
 
 #
@@ -53,30 +54,32 @@ proc find1 {dir depth updir} {
 
 	# matches in current directory
 #puts "$findx(rexpr) => [expr $findx(rexpr)]"
-	if ![expr $findx(rexpr)] return
+	if {[string equal $findx(rexpr) ""]} return
 #puts "[llength $findx(matches)], $depth"
-#	if {$dir!="/" && [catch {cd [file tail $dir]}]} return
-#puts [expr {$dir!="/" && [catch {cd $dir}]}]
-	if [catch {cd $dir}] return
+#	if {![string equal $dir "/"] && [catch {cd [file tail $dir]}]} return
+#puts [expr {![string equal $dir "/"] && [catch {cd $dir}]}]
+	if {[catch {cd $dir}]} return
 #	set curdir [pwd]
 	set f(dir) $dir
 	foreach file [glob -nocomplain *] {
 		incr findx(seen)
-		#if {[pwd]!=$curdir} {cd $curdir}
-		if [catch {file lstat $file f}] continue
-		set subupdir ..; if {$f(type)=="link" && [file isdirectory $file]} {set f(type) "directory"; set subupdir [pwd]}
+		#if {![string equal [pwd] $curdir]} {cd $curdir}
+		if {[catch {file lstat $file f}]} continue
+		set subupdir ..; if {[string equal $f(type) "link"] && [file isdirectory $file]} {set f(type) "directory"; set subupdir [pwd]}
 		set f(tail) $file
 		set relpath [file join $dir $file]
 #puts "$findx(expr) => [expr $findx(expr)] ($file in $dir)"
-		if {[expr $findx(expr)]} {lappend findx(matches) $relpath}
+		# no brackets around $findx(expr)
+#puts "$findx(expr), file=$file => [subst $findx(expr)]"
+		if {[subst $findx(expr)]} {lappend findx(matches) $relpath}
 
 		# matches in subdirectories
 		if {[file isdirectory $relpath]} {
-			foreach match [find1 $relpath [expr $depth+1] $subupdir] {lappend findx(matches) $match}
+			foreach match [find1 $relpath [expr {$depth+1}] $subupdir] {lappend findx(matches) $match}
 		}
 	}
 #	cd ..; # weird symbolic links sometimes so [pwd]!=$curdir kludge above
-#if {$updir!=".."} {puts "$dir up to $updir"}
+#if {![string equal $updir ".."]} {puts "$dir up to $updir"}
 	cd $updir
 }
 
@@ -96,19 +99,10 @@ proc pipeexp {p} {
 proc assert {bool msg {boom 0}} {
 	if {!$bool} {
 		puts stderr $msg
-		if $boom {exit 1}
+		if {$boom} {exit 1}
 	}
 }
 
-# pass in # and `s' or `es'
-proc plural {cnt word {s ""}} {
-	if {$cnt!=1 && $cnt!=-1} {
-		if {$s==""} { if {[string index [string tolower $word] [expr [string length $word]-1]]=="s"} {set s "es"} else {set s "s"}}
-		append word $s
-	}
-	return $word
-}
-
 # fileexp perform file spec expansion: ~ . .. $
 proc fileexp {f} {
 	global env
@@ -121,9 +115,10 @@ proc fileexp {f} {
 	foreach i [split $f "/"] {
 		switch -glob $i {
 			"" {set dir ""}
+			{[A-Za-z]:} {set dir "$i/"}
 			~  {set dir $env(HOME)}
 	 $* {set val $env([string trim [string range $i 1 end] ()])
-				 if {[string match /* $val]} {set dir $val} {append expf /$val)}}
+				 if {[string match /* $val]} {set dir $val} else {append expf /$val)}}
 			.  {set dir $dir}
 	 .. {set dir [file dirname $dir]}
 	 default {append expf /$i}
@@ -142,18 +137,18 @@ proc fileexp {f} {
 # on /usr/sww/, Tcl's file tail returns sww -- want ""
 proc filetail {f} {
 	set tail [file tail $f]
-	if [string match */ $f] {set tail ""}
+	if {[string match */ $f]} {set tail ""}
 	return $tail
 }
 proc filedirname {f} {
 	set dirname [file dirname $f]
-	if [string match ?*/ $f] {set dirname [string range $f 0 [expr [string length $f]-2]]}
+	if {[string match ?*/ $f]} {set dirname [string range $f 0 [expr {[string length $f]-2}]]}
 	return $dirname
 }
 
 proc filecomplete {f} {
 	set expf [fileexp [filedirname $f]]/[filetail $f]
-	set posn [string last [filetail $f] $f]; if [string match */ $f] { set posn [string length $f] }
+	set posn [string last [filetail $f] $f]; if {[string match */ $f]} {set posn [string length $f]}
 	#if [string match */ $f] {set expf $f; set tail ""; set posn [string length $f]}
 #puts "$posn, expf=$expf"
 	set l [glob -nocomplain $expf*]
@@ -169,13 +164,12 @@ proc filecomplete {f} {
 		# determine the longest common prefix
 		set lf [lfirst $l]; set lfl [string length $lf]
 		set last $lfl
-		set ni [expr [string last / $lf]+1]
+		set ni [expr {[string last / $lf]+1}]
 		foreach i $l {
-			set il [string length $i]
 			for {set j $ni} {$j<=$last} {incr j} {
-				if {[string range $lf $j $j]!=[string range $i $j $j]} break
+				if {![string equal [string index $lf $j] [string index $i $j]]} break
 			}
-			set last [min $last [expr $j-1]]
+			set last [min $last [expr {$j-1}]]
 		}
 		set tail [filetail [string range [lfirst $l] 0 $last]]
 	}
@@ -184,21 +178,13 @@ proc filecomplete {f} {
 	# compose original directory specification with (possibly) new tail
 	if {$posn>0 && $ll} {
 		# can't use dirname because it expands ~'s
-		set tail [string range $f 0 [expr $posn-1]]$tail
+		set tail [string range $f 0 [expr {$posn-1}]]$tail
 	}
 
-	if {$ll<2} {return $tail} {return "$tail $l"}
+	if {$ll<2} {return $tail} else {return "$tail $l"}
 }
 
 
-#return [expr [string first $c "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"]!=-1]
-
-proc isalpha {c} {return [regexp -nocase {[a-z]} $c]}
-proc isnum {c} {return [expr [string first $c "123456790"]!=-1]}
-proc isalphanum {c} {return [expr [isalpha $c]||[isnum $c]]}
-
-proc stringicap {s} {return [string toupper [string range $s 0 0]][string range $s 1 end]}
-
 proc tr {s c1 c2} {
 #	regsub -all \\$c1 $s $c2 s2
 	regsub -all "\[$c1\]" $s $c2 s2
@@ -209,10 +195,10 @@ proc tr {s c1 c2} {
 #    pass expanded filename, list of shortenings
 #set file(globList) ~
 proc bolg {f {l ""}} {
-	if {$l==""} {global file; set l $file(globList)}
+	if {[string equal $l ""]} {global file; set l $file(globList)}
 
 	foreach i $l {
-		if [regsub ([glob -nocomplain $i])(.*) $f "$i\\2" short] {return $short}
+		if {[regsub ([glob -nocomplain $i])(.*) $f "$i\\2" short]} {return $short}
 	}
 	return $f
 }
@@ -236,7 +222,7 @@ proc unsplit {l c} {
 		append l2 $i $c
 	}
 #   return [string trimright $l2 $c]
-	return [string range $l2 0 [expr [string length $l2]-2]]
+	return [string range $l2 0 [expr {[string length $l2]-2}]]
 }
 
 proc bytes2prefix {x} {
@@ -249,9 +235,9 @@ proc bytes2prefix {x} {
 	set y BIG
 	for {set i 0} {$i<[llength $pfx]} {incr i} {
 		if {$x<$sz} {
-			return [format " %0.1f [lindex $pfx $i]" [expr $x/($sz/$k)]]
+			return [format " %0.1f [lindex $pfx $i]" [expr {$x/($sz/$k)}]]
 		}
-		set sz [expr $sz*$k]
+		set sz [expr {$sz*$k}]
 	}
 }
 
@@ -269,7 +255,7 @@ proc uniqlist {l} {
 	set e ""
 	set l2 ""
 	foreach i $l {
-		if {$e!=$i} {
+		if {![string equal $e $i]} {
 			lappend l2 $i
 			set e $i
 		}
@@ -290,10 +276,10 @@ proc min {args} {
 proc avg {args} {
 	set sum 0.0
 
-	if {$args==""} return
+	if {[string $args ""]} return
 	
-	foreach i $args {set sum [expr $sum+$i]}
-	return [expr ($sum+0.0)/[llength $args]]
+	foreach i $args {set sum [expr {$sum+$i}]}
+	return [expr {($sum+0.0)/[llength $args]}]
 }
 
 proc max {args} {
@@ -317,9 +303,7 @@ proc lseventh {l} {return [lindex $l 6]}
 proc lrest {l} {return [lrange $l 1 end]}
 
 proc llast {l} {
-	set end [llength $l]
-	if {!$end} {return ""}
-	return [lindex $l [expr $end-1]]
+	return [lindex $l end]
 }
 
 proc setappend {l e} {
@@ -331,7 +315,7 @@ proc lfilter {p l} {
 	set l2 ""
 
 	foreach i $l {
-		if ![string match $p $i] "lappend l2 [list $i]"
+		if {![string match $p $i]} "lappend l2 [list $i]"
 	}
 	return $l2
 }
@@ -339,7 +323,7 @@ proc lfilter {p l} {
 # keep elements matching pattern p in list l
 proc lmatches {p l} {
 	set l2 ""
-	foreach i $l { if [string match $p $i] {lappend l2 [list $i]} }
+	foreach i $l { if {[string match $p $i]} {lappend l2 [list $i]} }
 	return $l2
 }
 
@@ -369,9 +353,8 @@ proc lbssoc {l k} {
 
 proc lreverse {l {block 1}} {
 	set lrev {}
-	set llen [llength $l]
-	for {set i [expr $llen-$block]} {$i>=0} {incr i -$block} {
-		lappend lrev [lrange $l $i [expr $i+$block-1]]
+	for {set i [expr {[llength $l]-$block}]} {$i>=0} {incr i -$block} {
+		lappend lrev [lrange $l $i [expr {$i+$block-1}]]
 	}
 	set flatten [eval concat $lrev]
 	return $flatten
@@ -383,13 +366,13 @@ proc lreverse {l {block 1}} {
 #
 
 proc geom2posn {g} {
-	if [regexp {(=?[0-9]+x[0-9]+)([-+]+[0-9]+[-+]+[0-9]+)} $g both d p] {
+	if {[regexp {(=?\d+x\d+)([-+]+\d+[-+]+\d+)} $g both d p]} {
 		return $p
 	} else { return $g }
 }
 
 proc geom2size {g} {
-	if [regexp {(=?[0-9]+x[0-9]+)([-+]+[0-9]+[-+]+[0-9]+)} $g both d p] {
+	if {[regexp {(=?\d+x\d+)([-+]+\d+[-+]+\d+)} $g both d p]} {
 		return $d
 	} else { return $g }
 }
@@ -429,15 +412,15 @@ proc key_state2mnemon {n} {
 
 	for {set bp 0} {$bp<[string length $trans]} {incr bp} {
 		set t [string index $trans $bp]
-		if {$t!=" " && $n&(1<<$bp)} {append mod $t}
+		if {![string equal $t " "] && $n&(1<<$bp)} {append mod $t}
 	}
 
 	return $mod
 }
 
 proc lmatch {mode list {pattern ""}} {
-	if {$pattern==""} {set pattern $list; set list $mode; set mode "-glob"}
-	return [expr [lsearch $mode $list $pattern]!=-1]
+	if {[string equal $pattern ""]} {set pattern $list; set list $mode; set mode "-glob"}
+	return [expr {[lsearch $mode $list $pattern]!=-1}]
 }
 
 
@@ -452,9 +435,12 @@ proc stringremove {s {c " "}} {
 # backquote all regular expression meta-characters
 proc stringregexpesc {s} { 
 	return [stringesc $s {\||\*|\+|\?|\.|\^|\$|\\|\[|\]|\(|\)|\-}]
+# try this:	return [stringesc $s {[][|*+?.^$\\()-]}]
+#	return [stringesc $s {[\|\*\+\?\.\^\$\\\[\]\(\)\-]}]
 }
 # backquote Tcl meta-characters
-proc stringesc {s {c {\\|\$|\[|\{|\}|\]|\"}}} {
+#proc stringesc {s {c {\\|\$|\[|\{|\}|\]|\"}}} {
+proc stringesc {s {c {[][\\\${}"]}}} {
 	regsub -all -- $c $s {\\&} s2
 	return $s2
 }
@@ -475,7 +461,7 @@ proc listboxshowS {lb s {first 0} {cnstr yes}} {
 	set sz [$lb size]
 
 	for {set i $first} {$i<$sz} {incr i} {
-		if [string match $s [$lb get $i]] {
+		if {[string match $s [$lb get $i]]} {
 			listboxshowI $lb $i $cnstr
 			return $i
 		}
@@ -485,11 +471,11 @@ proc listboxshowS {lb s {first 0} {cnstr yes}} {
 
 proc listboxshowI {lb high {cnstr yes}} {
 #   if {$high>=[$lb size] || $high<0} return
-	set high [max 0 [min $high [expr [$lb size]-1]]]
+	set high [max 0 [min $high [expr {[$lb size]-1}]]]
 
 	set hb [lindex [split [$lb cget -geometry] x] 1]
-	set hx [max 0 [expr [$lb size]-$hb]]
-	if {$cnstr=="yes"} {set hl [expr $high<$hb?0:[min $high $hx]]} {set hl $high}
+	set hx [max 0 [expr {[$lb size]-$hb}]]
+	if {[string equal $cnstr "yes"]} {set hl [expr {$high<$hb?0:[min $high $hx]}]} else {set hl $high}
 	$lb select from $high
 	$lb yview $hl
 }
@@ -543,13 +529,13 @@ option add *Text.borderwidth 2
 
 
 proc tabgroup {args} {
-	if [llength $args]==1 {set wins [lindex $args 0]} {set wins $args}
+	if {[llength $args]==1} {set wins [lindex $args 0]} else {set wins $args}
 
 	set l [llength $wins]
 	for {set i 0} {$i<$l} {incr i} {
 		set w [lindex $wins $i]
-		set pw [lindex $wins [expr ($i-1)%$l]]
-		set nw [lindex $wins [expr ($i+1)%$l]]
+		set pw [lindex $wins [expr {($i-1)%$l}]]
+		set nw [lindex $wins [expr {($i+1)%$l}]]
 
 		bind $w <KeyPress-Tab> "focus $nw; break"
 		bind $w <Shift-KeyPress-Tab> "focus $pw; break"
@@ -561,11 +547,12 @@ proc winstderr {w msg {type "bell & flash"}} {
 	if {![winfo exists $w]} return
 	set bell [string match "*bell*" $type]
 	set flash [string match "*flash*" $type]
+#	regsub -all "\n" $msg " // " msg
 
 	set fg [$w cget -foreground]; set bg [$w cget -background]
 
-	set msgout [string range $msg 0 500]
-	if {[string length $msg]>500} {
+	set msgout [string range $msg 0 250]
+	if {[string length $msg]>250} {
 		append msgout " ... (truncated; full message sent to stdout)"
 		puts stderr $msg
 	}
@@ -580,9 +567,9 @@ proc winstderr {w msg {type "bell & flash"}} {
 
 proc winstdout {w {msg AnUnLiKeMeSsAgE} {update 0}} {
 	if {![winfo exists $w]} return
-	if {$update=="update"} {set update 1}
+	if {[string equal $update "update"]} {set update 1}
 
-	if {$msg!="AnUnLiKeMeSsAgE"} {
+	if {![string equal $msg "AnUnLiKeMeSsAgE"]} {
 		$w configure -text $msg
 		if {$update} { update idletasks }
 	}
@@ -590,7 +577,7 @@ proc winstdout {w {msg AnUnLiKeMeSsAgE} {update 0}} {
 }
 
 proc yviewcontext {w l c} {
-	if {$l=="sel"} {
+	if {[string equal $l "sel"]} {
 		set cnt [scan [$w tag ranges sel] %d l]
 		if {$cnt<=0} return
 	}
@@ -598,7 +585,7 @@ proc yviewcontext {w l c} {
 	incr l -1; # 0-based!
 
 	scan [$w index end] %d n
-	set prev [expr $l-$c]; set next [expr $l+$c]
+	set prev [expr {$l-$c}]; set next [expr {$l+$c}]
 
 	if {$prev>=0} {$w yview -pickplace $prev}
 	if {$next<=$n} {$w yview -pickplace $next}
@@ -607,10 +594,10 @@ proc yviewcontext {w l c} {
 
 
 proc screencenter {xy wh} {
-	if {$xy=="x"} {
-		return [expr ([winfo screenwidth .]-$wh)/2]
-	} {
-		return [expr ([winfo screenheight .]-$wh)/2]
+	if {[string equal $xy "x"]} {
+		return [expr {([winfo screenwidth .]-$wh)/2}]
+	} else {
+		return [expr {([winfo screenheight .]-$wh)/2}]
 	}
 }
 
@@ -626,13 +613,13 @@ proc screencenter {xy wh} {
 #}
 
 proc cursorBusy {{up 1}} {
-	if {[. cget -cursor]!="watch"} {
-		cursorSet watch; if $up {update idletasks}
+	if {![string equal [. cget -cursor] "watch"]} {
+		cursorSet watch; if {$up} {update idletasks}
 	}
 }
 proc cursorSet {c {w .}} {
 	global cursor
-#if {$w=="."} {puts "cursorSet"}
+#if {[string equal $w "."]} {puts "cursorSet"}
 	set cursor($w) [$w cget -cursor]
 #puts "cursor($w) = $cursor($w)"
 	$w configure -cursor $c
@@ -640,99 +627,29 @@ proc cursorSet {c {w .}} {
 }
 proc cursorUnset {{w .}} {
 	global cursor
-#if {$w=="."} {puts "cursorUnset"}
+#if {[string equal $w "."]} {puts "cursorUnset"}
 	catch {$w configure -cursor $cursor($w)}
 	foreach child [winfo children $w] {cursorUnset $child}
 }
 
-proc mon2Month {m} {
-	set mons {jan feb mar apr may jun jul aug sep oct nov dec}
-	set Months {January February March April May June July August September October November December}
-	set ml [string tolower $m]
-	if {[set x [lsearch -exact $mons $ml]]!=-1} {
-		set m [lindex $Months $x]
-	}
-
-	return $m
-}
-
 proc configurestate {wins {flag "menu"}} {
 	set flag0 $flag
 	foreach w $wins {
 		set flag $flag0
-		if {$flag=="menu"} {
-			if {[winfo class $w]=="Menubutton"} {
+		if {[string equal $flag "menu"]} {
+			if {[string equal [winfo class $w] "Menubutton"]} {
 				set m [$w cget -menu]; set end [$m index end]
-				set flag [expr {$end!="none" && (![$m cget -tearoff] || $end>0)} ]
+				set flag [expr {![string equal $end "none"] && (![$m cget -tearoff] || $end>0)} ]
 			} else { set flag 0 }
 		}
-		$w configure -state [expr $flag?"normal":"disabled"]
+		$w configure -state [expr {$flag?"normal":"disabled"}]
 	}
 }
 
-proc linebreak {string {breakat 70}} {
-	set ch 0; set lastw ""
-	set broke ""
-
-	foreach word $string {
-		# double space after periods
-		if {[string match "*." $lastw]} {append broke " "}
-
-		set wlen [string length $word]
-		if {$ch+$wlen<$breakat} {
-			if {$ch>0} {append broke " "; incr ch}
-			append broke $word; incr ch $wlen
-		} else {
-			append broke "\n" $word
-			set ch $wlen
-		}
-
-		set lastw $word
-	}
-
-	return $broke
-}
-
-
-# return dates like ls: the more recent the more information, in roughly same number of characters
-proc recently {then} {
-	set datainfo "%Y %B %d %H %M %S"
-	set format "%d %s %d %d %s %s"
-	set now [clock seconds]
-	scan [clock format $now -format $datainfo] $format year month day hour min sec
-	set midnight [clock scan "$day $month"]
-	scan [clock format $then -format $datainfo] $format oyear omonth oday ohour omin osec
-
-	set secday [expr 24*60*60]
-	set secmonth [expr 30*$secday]
-	set secyear [expr 365*$secday]
-
-	set age [expr $now-$then]
-	if {$age>=[expr $secyear-2*$secmonth]} {
-		set r "$oday $omonth $oyear"
-	} else {
-		if {$age>=$secmonth} {
-			set r "$ohour:$omin, $oday $omonth"
-		} else {
-			set r "$ohour:$omin"
-			if {[expr $midnight-$secday]>=$then} {
-				append r ", $oday $omonth"
-			} else {
-				if {$day!=$oday} {
-					append r " yesterday"
-				} else { append r ":$osec today" }
-			}
-		}
-	}
-
-	return $r
-}
-
-
 # Tk-related
 
 # singleton menu
 proc smenu {m args} {
-	if ![winfo exists $m] {eval menu $m $args}
+	if {![winfo exists $m]} {eval menu $m $args}
 	return $m
 }
